
DROP SCHEMA work CASCADE;
CREATE SCHEMA work;


--
-- Name: update_statistics; Type: TYPE; Schema: work; Owner: -
--

CREATE TYPE work.update_statistics AS (
	new_documents integer,
	updated_documents integer,
	deleted_containers integer,
	inserted_containers integer
);


--
-- Name: f_analyze_work_tbls(); Type: FUNCTION; Schema: work; Owner: -
--

CREATE FUNCTION work.f_analyze_work_tbls() RETURNS boolean
    LANGUAGE plperl
    AS $_$

  my $sql = "select *
             from information_schema.tables
             where table_schema='work'
               and table_type='BASE TABLE'";
  my $rv = spi_exec_query($sql);
  my $status = $rv->{status};
  my $nrows = $rv->{processed};
  elog(NOTICE, "analyzing $nrows tables ...");
  my @statements = ();
  
  foreach my $rn (0 .. $nrows - 1) {
    my $row = $rv->{rows}[$rn];
    push(@statements, "analyze work.$row->{table_name}");
  }

  foreach my $statement (@statements) {
    spi_exec_query($statement);
  }

return 1;
$_$;


--
-- Name: f_client_update_all(boolean); Type: FUNCTION; Schema: work; Owner: -
--

CREATE FUNCTION work.f_client_update_all(v_force boolean DEFAULT false, OUT v_stats work.update_statistics) RETURNS work.update_statistics
    LANGUAGE plpgsql
    AS $$

DECLARE
  v_load_id integer;
  v_load_source text;

BEGIN

  select max(modified_load_id) into v_load_id from work.t_patent_document_values;
  select load_source into v_load_source from reporting.t_client_load_process where load_id=v_load_id;
  if not found then
    select load_source into v_load_source from reporting.t_load_process where load_id=v_load_id;
  end if;

  select * into v_stats from work.f_update_all_load_source(v_load_source);

END

$$;


--
-- Name: f_delete_all(); Type: FUNCTION; Schema: work; Owner: -
--

CREATE FUNCTION work.f_delete_all() RETURNS integer
    LANGUAGE plperl
    AS $_$

  my $deleted = 0;
  my $sql = "select *
             from information_schema.tables
             where table_schema='xml'
               and table_type='BASE TABLE'
               and table_name!='t_sys_data'
             order by table_name";
  my $rv = spi_exec_query($sql);
  my $status = $rv->{status};
  my $nrows = $rv->{processed};
  my @statements = ();
  
  foreach my $rn (0 .. $nrows - 1) {
    my $row = $rv->{rows}[$rn];
    my %h = (
      tbl => "xml.$row->{table_name}",
      sql => "delete from xml.$row->{table_name} where publication_id
  in (select w.publication_id from work.t_patent_document_values w)" );
    push(@statements, \%h);
  }

  foreach my $ref (@statements) {
    $rv = spi_exec_query($ref->{sql});
    elog(INFO, "$ref->{tbl}: deleted $rv->{processed} existing rows");
    $deleted += $rv->{processed};
  }

return $deleted;
$_$;


--
-- Name: f_delete_all_update(); Type: FUNCTION; Schema: work; Owner: -
--

CREATE FUNCTION work.f_delete_all_update() RETURNS integer
    LANGUAGE plperl
    AS $_$

  my $deleted = 0;
  my $sql = "select *
             from information_schema.tables
             where table_schema='xml'
               and table_type='BASE TABLE'
               and table_name not in ('t_sys_data', 't_patent_document_values')
             order by table_name";
  my $rv = spi_exec_query($sql);
  my $status = $rv->{status};
  my $nrows = $rv->{processed};
  my @statements = ();
  
  foreach my $rn (0 .. $nrows - 1) {
    my $row = $rv->{rows}[$rn];
    my %h = (
      tbl => "xml.$row->{table_name}",
      sql => "delete from xml.$row->{table_name} where publication_id in (select w.publication_id from work.t_patent_document_values w)"
    );
    push(@statements, \%h);
  }

  foreach my $ref (@statements) {
    $rv = spi_exec_query($ref->{sql});
    elog(INFO, "$ref->{tbl}: deleted $rv->{processed} existing rows");
    $deleted += $rv->{processed};
  }

return $deleted;
$_$;


--
-- Name: f_delete_all_withdrawn(); Type: FUNCTION; Schema: work; Owner: -
--

CREATE FUNCTION work.f_delete_all_withdrawn() RETURNS integer
    LANGUAGE plperl
    AS $_$

  my $deleted = 0;
  my $wrk_delete = 0;
  my $sql = "select *
             from information_schema.tables
             where table_schema='xml'
               and table_type='BASE TABLE'
               and table_name not in ('t_sys_data', 't_patent_document_values')
             order by table_name";
  my $rv = spi_exec_query($sql);
  my $status = $rv->{status};
  my $nrows = $rv->{processed};
  my @statements = ();
  
  foreach my $rn (0 .. $nrows - 1) {
    my $row = $rv->{rows}[$rn];
    my %h = (
      tbl => "$row->{table_name}",
      # handle documents already in the database...
      #xsql => "delete from  xml.$row->{table_name} where publication_id in (select w.publication_id from work.t_patent_document_values w where w.withdraw=true)",
      xsql => "delete from  xml.$row->{table_name} where publication_id in (select w.publication_id from work.t_patent_document_values w where w.withdraw=true or w.status='deleted')",
      # handle the rest ...
      # wsql => "delete from work.$row->{table_name} where publication_id in (select w.publication_id from work.t_patent_document_values w where w.withdraw=true)"
      wsql => "delete from work.$row->{table_name} where ucid in (select w.ucid from work.t_patent_document_values w where w.withdraw=true or w.status='deleted')"
    );
    push(@statements, \%h);
  }

  foreach my $ref (@statements) {
    $rv = spi_exec_query($ref->{xsql});
    $deleted += $rv->{processed};
    
    # do not allow updates from work either ...
    $rv = spi_exec_query($ref->{wsql});
    $wrk_deleted += $rv->{processed};
  }
  elog(INFO, "withdrawn: (XML) : deleted $deleted rows");
  elog(INFO, "withdrawn: (WORK): deleted $wrk_deleted rows");
return $deleted;
$_$;


--
-- Name: f_pre_update(); Type: FUNCTION; Schema: work; Owner: -
--

CREATE FUNCTION work.f_pre_update() RETURNS work.update_statistics
    LANGUAGE plpgsql
    AS $$

DECLARE
  v_stats work.update_statistics;
  v_cnt integer := 0;
BEGIN

  select 0,0,0,0 into v_stats;

  -- set all publication_id(s) to -1
  update work.t_patent_document_values
    set publication_id=-1;

  -- now try and match publication_id(s) based on ucid
  update work.t_patent_document_values as w
     set publication_id=x.publication_id
  from xml.t_patent_document_values as x
  where w.ucid=x.ucid;

  GET DIAGNOSTICS v_stats.updated_documents = ROW_COUNT;
  RAISE INFO 'work.t_patent_document_values (pre-update): matched % existing rows', v_stats.updated_documents;

  -- next ... generate NEW publication_id(s)
  perform setval('xml.seq_publication_id', (select max(publication_id) from xml.t_patent_document_values), true);
  update work.t_patent_document_values
    set publication_id=nextval('xml.seq_publication_id')
  where publication_id=-1;
  
  GET DIAGNOSTICS v_stats.new_documents = ROW_COUNT;
  RAISE INFO 'work.t_patent_document_values (pre-update): new publication_id generated for % rows', v_stats.new_documents;

  select count(*) into v_cnt from work.t_patent_document_values where withdraw=true or status='deleted';
  if (v_cnt > 0) then
    perform work.f_delete_all_withdrawn();
    -- set deleted load id
    update work.t_patent_document_values
    set deleted_load_id = modified_load_id
    where withdraw=true or status='deleted';
  end if;
  
  return v_stats;
END

$$;


--
-- Name: f_truncate_all(); Type: FUNCTION; Schema: work; Owner: -
--

CREATE FUNCTION work.f_truncate_all() RETURNS integer
    LANGUAGE plpgsql
    AS $_$

DECLARE
  v_table regclass;
BEGIN

  FOR v_table IN EXECUTE $$
    SELECT
       'work.' || table_name
     FROM
       information_schema.tables t1
         INNER JOIN
       information_schema.tables t2
         USING (table_name, table_type)
     WHERE t1.table_schema = 'xml'
       AND t2.table_schema = 'work'
       AND table_type = 'BASE TABLE'
       AND table_name != 't_sys_data'
    ORDER BY table_name
  $$
  LOOP
    --RAISE INFO 'truncating %', v_table;
    EXECUTE FORMAT('TRUNCATE TABLE %s RESTART IDENTITY', v_table);
  END LOOP;

  RETURN 1;
  
END;

$_$;


--
-- Name: f_update_all(boolean); Type: FUNCTION; Schema: work; Owner: -
--

CREATE FUNCTION work.f_update_all(v_force boolean DEFAULT false, OUT v_stats work.update_statistics) RETURNS work.update_statistics
    LANGUAGE plpgsql
    AS $$

DECLARE
  v_load_id integer;
  v_load_source text;

BEGIN

  select max(modified_load_id) into v_load_id from work.t_patent_document_values;
  select load_source into v_load_source from reporting.t_client_load_process where load_id=v_load_id;
  if not found then
    select load_source into v_load_source from reporting.t_load_process where load_id=v_load_id;
  end if;

  select * into v_stats from work.f_update_all_load_source(v_load_source);

END

$$;


--
-- Name: f_update_all_load_source(text); Type: FUNCTION; Schema: work; Owner: -
--

CREATE FUNCTION work.f_update_all_load_source(v_load_source text DEFAULT ''::text, OUT v_stats work.update_statistics) RETURNS work.update_statistics
    LANGUAGE plpgsql
    AS $$

DECLARE
  v_stats_tmp work.update_statistics;
  v_table_query text;
  v_table text;
BEGIN

  SELECT 0,0,0,0 INTO v_stats;
  SELECT 0,0,0,0 INTO v_stats_tmp;

  PERFORM work.f_analyze_work_tbls();

  IF (v_load_source LIKE 'FV-%-DEL') THEN
    -- this signals f_pre_update() to:
    --    call f_delete_all_withdraw() and then
    --    SET deleted_load_id
    UPDATE work.t_patent_document_values set status='deleted';
  END IF;
  
  PERFORM work.f_pre_update();

  IF (v_load_source LIKE 'FV-%-REL') THEN
    RAISE INFO '% load source encountered, deleting existing data ...', v_load_source;
    SELECT work.f_delete_all_update() INTO v_stats.deleted_containers;
    RAISE INFO 'existing data deleted, % total rows removed', v_stats.deleted_containers;
  END IF;
  
  SELECT * INTO v_stats FROM work.f_update_t_patent_document_values();

  -- get the list of tables present in both the xml and work schemas
  v_table_query := 
    'SELECT table_name                                                                        
     FROM information_schema.tables t1
       INNER JOIN information_schema.tables t2
         USING (table_name, table_type)                                                     
     WHERE t1.table_schema = ''xml''
       AND t2.table_schema = ''work''                                                              
       AND table_type = ''BASE TABLE''                                                           
       AND table_name NOT IN (''t_patent_document_values'', ''t_sys_data'')
    ORDER BY table_name';

  FOR v_table IN EXECUTE v_table_query LOOP
    SELECT * INTO v_stats_tmp FROM work.f_update_table(v_table);
    -- SELECT * INTO v_stats_tmp FROM work.f_update_table_compare(v_table);
    v_stats.deleted_containers := v_stats.deleted_containers + v_stats_tmp.deleted_containers;
    v_stats.inserted_containers := v_stats.inserted_containers + v_stats_tmp.inserted_containers;
  END LOOP;

  RETURN;
END

$$;


--
-- Name: f_update_t_patent_document_values(); Type: FUNCTION; Schema: work; Owner: -
--

CREATE FUNCTION work.f_update_t_patent_document_values() RETURNS work.update_statistics
    LANGUAGE plpgsql
    AS $$

DECLARE
  v_stats work.update_statistics;
BEGIN

  select 0,0,0,0 into v_stats;

  insert into xml.t_patent_document_values
   (
     publication_id,
     ucid,
     lang,
     country,
     doc_number,
     kind,
     published,
     produced,
     withdraw,
     family_id,
     status,
     created_load_id,
     modified_load_id,
     deleted_load_id
   ) (
    select
     w.publication_id,
     w.ucid,
     w.lang,
     w.country,
     w.doc_number,
     w.kind,
     w.published,
     w.produced,
     w.withdraw,
     w.family_id,
     w.status,
     w.modified_load_id, -- created_load_id = modified_load_id for new documents
     w.modified_load_id,
     w.deleted_load_id
    from work.t_patent_document_values as w
      left outer join xml.t_patent_document_values as x on (w.publication_id=x.publication_id)
    where x.publication_id is null
  );
  
  GET DIAGNOSTICS v_stats.new_documents = ROW_COUNT;
  RAISE INFO 'xml.t_patent_document_values: inserted % new rows', v_stats.new_documents;

  update xml.t_patent_document_values as x
     set publication_id=w.publication_id,
         ucid=w.ucid,
         lang=w.lang, 
         country=w.country,
         doc_number=w.doc_number,
         kind=w.kind,
         published=w.published,
         produced=w.produced,
         withdraw=w.withdraw, 
         family_id=w.family_id,
         status=w.status,
         modified_load_id=w.modified_load_id,
         deleted_load_id=w.deleted_load_id
  from  work.t_patent_document_values as w
  where x.publication_id=w.publication_id
    and w.modified_load_id >= x.modified_load_id;


  GET DIAGNOSTICS v_stats.updated_documents = ROW_COUNT;
  RAISE INFO 'xml.t_patent_document_values: updated % existing rows', v_stats.updated_documents;

  return v_stats;
END

$$;


--
-- Name: f_update_table(text); Type: FUNCTION; Schema: work; Owner: -
--

CREATE FUNCTION work.f_update_table(v_table text, OUT v_stats work.update_statistics) RETURNS work.update_statistics
    LANGUAGE plpgsql
    AS $$

DECLARE
  v_xml_table text;
  v_work_table text;
  v_work_count int;

BEGIN

-- return value work.update_statistics holds four integer values:
--  new_documents, updated_documents, deleted_containers, inserted_containers
  select 0,0,0,0 into v_stats;

  v_xml_table := format('xml.%I', v_table);
  v_work_table := format('work.%I', v_table);
  
  -- set all publication_id(s) to -1
  EXECUTE format('UPDATE %s SET publication_id = -1', v_work_table);
  GET DIAGNOSTICS v_work_count = ROW_COUNT;
    
  -- if no records were found, return now
  IF v_work_count = 0 THEN
    RAISE LOG 'skipping %: no records found', v_work_table;
    RETURN;
  END IF;

  -- match all from work ( pre_update matched existing
  -- or created new publication_id(s) ) 
  EXECUTE format(
    'UPDATE %s w
    SET publication_id = p.publication_id
    FROM work.t_patent_document_values p
    WHERE w.ucid = p.ucid',
    v_work_table
  );

  -- delete all records from the xml table
  EXECUTE format(
    'DELETE FROM %s WHERE publication_id IN (
      SELECT publication_id
      FROM %s
      WHERE publication_id > 0
      ORDER BY publication_id
    )',
    v_xml_table,
    v_work_table
  );
  GET DIAGNOSTICS v_stats.deleted_containers = ROW_COUNT;
  RAISE INFO '%: deleted % existing rows', v_xml_table, v_stats.deleted_containers;
 
  -- insert all
  EXECUTE format(
    'INSERT INTO %s (publication_id, modified_load_id, status,content) (
      SELECT publication_id, modified_load_id, status, content
      FROM %s
      WHERE publication_id > 0
      ORDER BY publication_id
    )',
    v_xml_table,
    v_work_table
  );
  GET DIAGNOSTICS v_stats.inserted_containers = ROW_COUNT;
  RAISE INFO '%: inserted % new rows', v_xml_table, v_stats.inserted_containers;

  RETURN;
END

$$;


SET default_with_oids = false;

--
-- Name: t_abstract; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_abstract (
    abstract_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_abstract_abstract_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_abstract_abstract_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_abstract_abstract_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_abstract_abstract_id_seq OWNED BY work.t_abstract.abstract_id;


--
-- Name: t_amended_claims; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_amended_claims (
    amended_claims_id integer NOT NULL,
    publication_id integer,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_amended_claims_amended_claims_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_amended_claims_amended_claims_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_amended_claims_amended_claims_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_amended_claims_amended_claims_id_seq OWNED BY work.t_amended_claims.amended_claims_id;


--
-- Name: t_application_reference; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_application_reference (
    application_reference_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_application_reference_application_reference_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_application_reference_application_reference_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_application_reference_application_reference_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_application_reference_application_reference_id_seq OWNED BY work.t_application_reference.application_reference_id;


--
-- Name: t_attachments_external; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_attachments_external (
    attachments_external_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_attachments_external_attachments_external_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_attachments_external_attachments_external_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_attachments_external_attachments_external_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_attachments_external_attachments_external_id_seq OWNED BY work.t_attachments_external.attachments_external_id;


--
-- Name: t_citations; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_citations (
    citation_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_citations_citation_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_citations_citation_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_citations_citation_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_citations_citation_id_seq OWNED BY work.t_citations.citation_id;


--
-- Name: t_claims; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_claims (
    claims_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_claims_claims_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_claims_claims_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_claims_claims_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_claims_claims_id_seq OWNED BY work.t_claims.claims_id;


--
-- Name: t_classification_ecla; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_classification_ecla (
    classification_ecla_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_classification_ecla_classification_ecla_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_classification_ecla_classification_ecla_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_classification_ecla_classification_ecla_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_classification_ecla_classification_ecla_id_seq OWNED BY work.t_classification_ecla.classification_ecla_id;


--
-- Name: t_classification_ipc; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_classification_ipc (
    classification_ipc_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_classification_ipc_classification_ipc_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_classification_ipc_classification_ipc_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_classification_ipc_classification_ipc_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_classification_ipc_classification_ipc_id_seq OWNED BY work.t_classification_ipc.classification_ipc_id;


--
-- Name: t_classification_locarno; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_classification_locarno (
    classification_locarno_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_classification_locarno_classification_locarno_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_classification_locarno_classification_locarno_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_classification_locarno_classification_locarno_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_classification_locarno_classification_locarno_id_seq OWNED BY work.t_classification_locarno.classification_locarno_id;


--
-- Name: t_classification_national; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_classification_national (
    classification_national_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_classification_national_classification_national_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_classification_national_classification_national_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_classification_national_classification_national_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_classification_national_classification_national_id_seq OWNED BY work.t_classification_national.classification_national_id;


--
-- Name: t_classifications_cpc; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_classifications_cpc (
    classifications_cpc_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_classifications_cpc_classifications_cpc_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_classifications_cpc_classifications_cpc_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_classifications_cpc_classifications_cpc_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_classifications_cpc_classifications_cpc_id_seq OWNED BY work.t_classifications_cpc.classifications_cpc_id;


--
-- Name: t_classifications_ipcr; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_classifications_ipcr (
    classifications_ipcr_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_classifications_ipcr_classifications_ipcr_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_classifications_ipcr_classifications_ipcr_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_classifications_ipcr_classifications_ipcr_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_classifications_ipcr_classifications_ipcr_id_seq OWNED BY work.t_classifications_ipcr.classifications_ipcr_id;


--
-- Name: t_dates_of_public_availability; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_dates_of_public_availability (
    dates_of_public_availability_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_dates_of_public_availabilit_dates_of_public_availability__seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_dates_of_public_availabilit_dates_of_public_availability__seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_dates_of_public_availabilit_dates_of_public_availability__seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_dates_of_public_availabilit_dates_of_public_availability__seq OWNED BY work.t_dates_of_public_availability.dates_of_public_availability_id;


--
-- Name: t_description; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_description (
    description_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_description_description_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_description_description_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_description_description_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_description_description_id_seq OWNED BY work.t_description.description_id;


--
-- Name: t_designated_states; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_designated_states (
    designated_states integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_designated_states_designated_states_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_designated_states_designated_states_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_designated_states_designated_states_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_designated_states_designated_states_seq OWNED BY work.t_designated_states.designated_states;


--
-- Name: t_drawings; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_drawings (
    drawings_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_drawings_drawings_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_drawings_drawings_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_drawings_drawings_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_drawings_drawings_id_seq OWNED BY work.t_drawings.drawings_id;


--
-- Name: t_f_term_info; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_f_term_info (
    f_term_info_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_f_term_info_f_term_info_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_f_term_info_f_term_info_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_f_term_info_f_term_info_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_f_term_info_f_term_info_id_seq OWNED BY work.t_f_term_info.f_term_info_id;


--
-- Name: t_field_of_search; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_field_of_search (
    field_of_search_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_field_of_search_field_of_search_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_field_of_search_field_of_search_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_field_of_search_field_of_search_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_field_of_search_field_of_search_id_seq OWNED BY work.t_field_of_search.field_of_search_id;


--
-- Name: t_figures; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_figures (
    figure_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_figures_figure_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_figures_figure_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_figures_figure_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_figures_figure_id_seq OWNED BY work.t_figures.figure_id;


--
-- Name: t_ifi_annotated_data; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_ifi_annotated_data (
    ifi_annotated_data_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_ifi_annotated_data_ifi_annotated_data_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_ifi_annotated_data_ifi_annotated_data_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_ifi_annotated_data_ifi_annotated_data_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_ifi_annotated_data_ifi_annotated_data_id_seq OWNED BY work.t_ifi_annotated_data.ifi_annotated_data_id;


--
-- Name: t_ifi_integrated_content; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_ifi_integrated_content (
    ifi_integrated_content_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_ifi_integrated_content_ifi_integrated_content_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_ifi_integrated_content_ifi_integrated_content_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_ifi_integrated_content_ifi_integrated_content_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_ifi_integrated_content_ifi_integrated_content_id_seq OWNED BY work.t_ifi_integrated_content.ifi_integrated_content_id;


--
-- Name: t_international_convention_data; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_international_convention_data (
    international_convention_data integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_international_convention_da_international_convention_data_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_international_convention_da_international_convention_data_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_international_convention_da_international_convention_data_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_international_convention_da_international_convention_data_seq OWNED BY work.t_international_convention_data.international_convention_data;


--
-- Name: t_invention_title; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_invention_title (
    invention_title_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_invention_title_invention_title_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_invention_title_invention_title_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_invention_title_invention_title_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_invention_title_invention_title_id_seq OWNED BY work.t_invention_title.invention_title_id;


--
-- Name: t_keywords; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_keywords (
    keywords_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_keywords_keywords_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_keywords_keywords_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_keywords_keywords_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_keywords_keywords_id_seq OWNED BY work.t_keywords.keywords_id;


--
-- Name: t_legal_status; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_legal_status (
    legal_status_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_legal_status_legal_status_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_legal_status_legal_status_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_legal_status_legal_status_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_legal_status_legal_status_id_seq OWNED BY work.t_legal_status.legal_status_id;


--
-- Name: t_office_specific_data; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_office_specific_data (
    office_specific_data_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_office_specific_data_office_specific_data_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_office_specific_data_office_specific_data_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_office_specific_data_office_specific_data_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_office_specific_data_office_specific_data_id_seq OWNED BY work.t_office_specific_data.office_specific_data_id;


--
-- Name: t_parties; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_parties (
    parties_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_parties_parties_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_parties_parties_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_parties_parties_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_parties_parties_id_seq OWNED BY work.t_parties.parties_id;


--
-- Name: t_patent_document_values; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_patent_document_values (
    patent_document_value_id integer NOT NULL,
    publication_id integer NOT NULL,
    ucid character varying(32),
    lang character(2),
    country character(2),
    doc_number character varying(32),
    kind character varying(4),
    published date,
    produced date,
    withdraw boolean DEFAULT false,
    family_id integer,
    status character varying(16),
    modified_load_id integer NOT NULL,
    created_load_id integer,
    deleted_load_id integer
);


--
-- Name: t_patent_document_values_patent_document_value_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_patent_document_values_patent_document_value_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_patent_document_values_patent_document_value_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_patent_document_values_patent_document_value_id_seq OWNED BY work.t_patent_document_values.patent_document_value_id;


--
-- Name: t_priority_claims; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_priority_claims (
    priority_claims_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_priority_claims_priority_claims_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_priority_claims_priority_claims_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_priority_claims_priority_claims_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_priority_claims_priority_claims_id_seq OWNED BY work.t_priority_claims.priority_claims_id;


--
-- Name: t_publication_reference; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_publication_reference (
    publication_reference_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_publication_reference_publication_reference_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_publication_reference_publication_reference_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_publication_reference_publication_reference_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_publication_reference_publication_reference_id_seq OWNED BY work.t_publication_reference.publication_reference_id;


--
-- Name: t_related_documents; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_related_documents (
    related_documents_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_related_documents_related_documents_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_related_documents_related_documents_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_related_documents_related_documents_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_related_documents_related_documents_id_seq OWNED BY work.t_related_documents.related_documents_id;


--
-- Name: t_revision_history; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_revision_history (
    revision_history_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_revision_history_revision_history_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_revision_history_revision_history_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_revision_history_revision_history_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_revision_history_revision_history_id_seq OWNED BY work.t_revision_history.revision_history_id;


--
-- Name: t_rule_47_flag; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_rule_47_flag (
    rule_47_flag_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_rule_47_flag_rule_47_flag_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_rule_47_flag_rule_47_flag_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_rule_47_flag_rule_47_flag_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_rule_47_flag_rule_47_flag_id_seq OWNED BY work.t_rule_47_flag.rule_47_flag_id;


--
-- Name: t_search_report_data; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_search_report_data (
    search_report_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_search_report_data_search_report_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_search_report_data_search_report_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_search_report_data_search_report_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_search_report_data_search_report_id_seq OWNED BY work.t_search_report_data.search_report_id;


--
-- Name: t_statistical_information; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_statistical_information (
    statistical_information_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_statistical_information_statistical_information_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_statistical_information_statistical_information_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_statistical_information_statistical_information_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_statistical_information_statistical_information_id_seq OWNED BY work.t_statistical_information.statistical_information_id;


--
-- Name: t_sys_data; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_sys_data (
    sys_data_id integer NOT NULL,
    copyright text
);


--
-- Name: t_sys_data_sys_data_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_sys_data_sys_data_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_sys_data_sys_data_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_sys_data_sys_data_id_seq OWNED BY work.t_sys_data.sys_data_id;


--
-- Name: t_technical_data; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_technical_data (
    technical_data_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_technical_data_technical_data_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_technical_data_technical_data_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_technical_data_technical_data_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_technical_data_technical_data_id_seq OWNED BY work.t_technical_data.technical_data_id;


--
-- Name: t_term_of_grant; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_term_of_grant (
    term_of_grant_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_term_of_grant_term_of_grant_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_term_of_grant_term_of_grant_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_term_of_grant_term_of_grant_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_term_of_grant_term_of_grant_id_seq OWNED BY work.t_term_of_grant.term_of_grant_id;


--
-- Name: t_us_sir_flag; Type: TABLE; Schema: work; Owner: -
--

CREATE UNLOGGED TABLE work.t_us_sir_flag (
    us_sir_flag_id integer NOT NULL,
    publication_id integer NOT NULL,
    modified_load_id integer NOT NULL,
    status character(1),
    content xml,
    ucid character varying(64)
);


--
-- Name: t_us_sir_flag_us_sir_flag_id_seq; Type: SEQUENCE; Schema: work; Owner: -
--

CREATE SEQUENCE work.t_us_sir_flag_us_sir_flag_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: t_us_sir_flag_us_sir_flag_id_seq; Type: SEQUENCE OWNED BY; Schema: work; Owner: -
--

ALTER SEQUENCE work.t_us_sir_flag_us_sir_flag_id_seq OWNED BY work.t_us_sir_flag.us_sir_flag_id;


--
-- Name: v_agents; Type: VIEW; Schema: work; Owner: -
--

CREATE VIEW work.v_agents AS
 SELECT t_parties.parties_id,
    t_parties.publication_id,
    t_parties.modified_load_id,
    t_parties.status,
    unnest(xpath('/parties/agents'::text, t_parties.content)) AS content
   FROM work.t_parties;


--
-- Name: v_applicants; Type: VIEW; Schema: work; Owner: -
--

CREATE VIEW work.v_applicants AS
 SELECT t_parties.parties_id,
    t_parties.publication_id,
    t_parties.modified_load_id,
    t_parties.status,
    unnest(xpath('/parties/applicants'::text, t_parties.content)) AS content
   FROM work.t_parties;


--
-- Name: v_assignee_history; Type: VIEW; Schema: work; Owner: -
--

CREATE VIEW work.v_assignee_history AS
 SELECT t_parties.parties_id,
    t_parties.publication_id,
    t_parties.modified_load_id,
    t_parties.status,
    unnest(xpath('/parties/assignee_history'::text, t_parties.content)) AS content
   FROM work.t_parties;


--
-- Name: v_assignees; Type: VIEW; Schema: work; Owner: -
--

CREATE VIEW work.v_assignees AS
 SELECT t_parties.parties_id,
    t_parties.publication_id,
    t_parties.modified_load_id,
    t_parties.status,
    unnest(xpath('/parties/assignees'::text, t_parties.content)) AS content
   FROM work.t_parties;


--
-- Name: v_correspondence_address; Type: VIEW; Schema: work; Owner: -
--

CREATE VIEW work.v_correspondence_address AS
 SELECT t_parties.parties_id,
    t_parties.publication_id,
    t_parties.modified_load_id,
    t_parties.status,
    unnest(xpath('/parties/correspondence_address'::text, t_parties.content)) AS content
   FROM work.t_parties;


--
-- Name: v_current_statistics; Type: VIEW; Schema: work; Owner: -
--

CREATE VIEW work.v_current_statistics AS
 SELECT t_patent_document_values.published,
    t_patent_document_values.country,
    count(*) AS count
   FROM work.t_patent_document_values
  GROUP BY t_patent_document_values.published, t_patent_document_values.country
  ORDER BY t_patent_document_values.published, t_patent_document_values.country;


--
-- Name: v_examiners; Type: VIEW; Schema: work; Owner: -
--

CREATE VIEW work.v_examiners AS
 SELECT t_parties.parties_id,
    t_parties.publication_id,
    t_parties.modified_load_id,
    t_parties.status,
    unnest(xpath('/parties/examiners'::text, t_parties.content)) AS content
   FROM work.t_parties;


--
-- Name: v_inventors; Type: VIEW; Schema: work; Owner: -
--

CREATE VIEW work.v_inventors AS
 SELECT t_parties.parties_id,
    t_parties.publication_id,
    t_parties.modified_load_id,
    t_parties.status,
    unnest(xpath('/parties/inventors'::text, t_parties.content)) AS content
   FROM work.t_parties;


--
-- Name: t_abstract abstract_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_abstract ALTER COLUMN abstract_id SET DEFAULT nextval('work.t_abstract_abstract_id_seq'::regclass);


--
-- Name: t_amended_claims amended_claims_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_amended_claims ALTER COLUMN amended_claims_id SET DEFAULT nextval('work.t_amended_claims_amended_claims_id_seq'::regclass);


--
-- Name: t_application_reference application_reference_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_application_reference ALTER COLUMN application_reference_id SET DEFAULT nextval('work.t_application_reference_application_reference_id_seq'::regclass);


--
-- Name: t_attachments_external attachments_external_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_attachments_external ALTER COLUMN attachments_external_id SET DEFAULT nextval('work.t_attachments_external_attachments_external_id_seq'::regclass);


--
-- Name: t_citations citation_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_citations ALTER COLUMN citation_id SET DEFAULT nextval('work.t_citations_citation_id_seq'::regclass);


--
-- Name: t_claims claims_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_claims ALTER COLUMN claims_id SET DEFAULT nextval('work.t_claims_claims_id_seq'::regclass);


--
-- Name: t_classification_ecla classification_ecla_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_classification_ecla ALTER COLUMN classification_ecla_id SET DEFAULT nextval('work.t_classification_ecla_classification_ecla_id_seq'::regclass);


--
-- Name: t_classification_ipc classification_ipc_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_classification_ipc ALTER COLUMN classification_ipc_id SET DEFAULT nextval('work.t_classification_ipc_classification_ipc_id_seq'::regclass);


--
-- Name: t_classification_locarno classification_locarno_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_classification_locarno ALTER COLUMN classification_locarno_id SET DEFAULT nextval('work.t_classification_locarno_classification_locarno_id_seq'::regclass);


--
-- Name: t_classification_national classification_national_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_classification_national ALTER COLUMN classification_national_id SET DEFAULT nextval('work.t_classification_national_classification_national_id_seq'::regclass);


--
-- Name: t_classifications_cpc classifications_cpc_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_classifications_cpc ALTER COLUMN classifications_cpc_id SET DEFAULT nextval('work.t_classifications_cpc_classifications_cpc_id_seq'::regclass);


--
-- Name: t_classifications_ipcr classifications_ipcr_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_classifications_ipcr ALTER COLUMN classifications_ipcr_id SET DEFAULT nextval('work.t_classifications_ipcr_classifications_ipcr_id_seq'::regclass);


--
-- Name: t_dates_of_public_availability dates_of_public_availability_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_dates_of_public_availability ALTER COLUMN dates_of_public_availability_id SET DEFAULT nextval('work.t_dates_of_public_availabilit_dates_of_public_availability__seq'::regclass);


--
-- Name: t_description description_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_description ALTER COLUMN description_id SET DEFAULT nextval('work.t_description_description_id_seq'::regclass);


--
-- Name: t_designated_states designated_states; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_designated_states ALTER COLUMN designated_states SET DEFAULT nextval('work.t_designated_states_designated_states_seq'::regclass);


--
-- Name: t_drawings drawings_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_drawings ALTER COLUMN drawings_id SET DEFAULT nextval('work.t_drawings_drawings_id_seq'::regclass);


--
-- Name: t_f_term_info f_term_info_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_f_term_info ALTER COLUMN f_term_info_id SET DEFAULT nextval('work.t_f_term_info_f_term_info_id_seq'::regclass);


--
-- Name: t_field_of_search field_of_search_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_field_of_search ALTER COLUMN field_of_search_id SET DEFAULT nextval('work.t_field_of_search_field_of_search_id_seq'::regclass);


--
-- Name: t_figures figure_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_figures ALTER COLUMN figure_id SET DEFAULT nextval('work.t_figures_figure_id_seq'::regclass);


--
-- Name: t_ifi_annotated_data ifi_annotated_data_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_ifi_annotated_data ALTER COLUMN ifi_annotated_data_id SET DEFAULT nextval('work.t_ifi_annotated_data_ifi_annotated_data_id_seq'::regclass);


--
-- Name: t_ifi_integrated_content ifi_integrated_content_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_ifi_integrated_content ALTER COLUMN ifi_integrated_content_id SET DEFAULT nextval('work.t_ifi_integrated_content_ifi_integrated_content_id_seq'::regclass);


--
-- Name: t_international_convention_data international_convention_data; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_international_convention_data ALTER COLUMN international_convention_data SET DEFAULT nextval('work.t_international_convention_da_international_convention_data_seq'::regclass);


--
-- Name: t_invention_title invention_title_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_invention_title ALTER COLUMN invention_title_id SET DEFAULT nextval('work.t_invention_title_invention_title_id_seq'::regclass);


--
-- Name: t_keywords keywords_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_keywords ALTER COLUMN keywords_id SET DEFAULT nextval('work.t_keywords_keywords_id_seq'::regclass);


--
-- Name: t_legal_status legal_status_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_legal_status ALTER COLUMN legal_status_id SET DEFAULT nextval('work.t_legal_status_legal_status_id_seq'::regclass);


--
-- Name: t_office_specific_data office_specific_data_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_office_specific_data ALTER COLUMN office_specific_data_id SET DEFAULT nextval('work.t_office_specific_data_office_specific_data_id_seq'::regclass);


--
-- Name: t_parties parties_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_parties ALTER COLUMN parties_id SET DEFAULT nextval('work.t_parties_parties_id_seq'::regclass);


--
-- Name: t_patent_document_values patent_document_value_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_patent_document_values ALTER COLUMN patent_document_value_id SET DEFAULT nextval('work.t_patent_document_values_patent_document_value_id_seq'::regclass);


--
-- Name: t_priority_claims priority_claims_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_priority_claims ALTER COLUMN priority_claims_id SET DEFAULT nextval('work.t_priority_claims_priority_claims_id_seq'::regclass);


--
-- Name: t_publication_reference publication_reference_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_publication_reference ALTER COLUMN publication_reference_id SET DEFAULT nextval('work.t_publication_reference_publication_reference_id_seq'::regclass);


--
-- Name: t_related_documents related_documents_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_related_documents ALTER COLUMN related_documents_id SET DEFAULT nextval('work.t_related_documents_related_documents_id_seq'::regclass);


--
-- Name: t_revision_history revision_history_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_revision_history ALTER COLUMN revision_history_id SET DEFAULT nextval('work.t_revision_history_revision_history_id_seq'::regclass);


--
-- Name: t_rule_47_flag rule_47_flag_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_rule_47_flag ALTER COLUMN rule_47_flag_id SET DEFAULT nextval('work.t_rule_47_flag_rule_47_flag_id_seq'::regclass);


--
-- Name: t_search_report_data search_report_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_search_report_data ALTER COLUMN search_report_id SET DEFAULT nextval('work.t_search_report_data_search_report_id_seq'::regclass);


--
-- Name: t_statistical_information statistical_information_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_statistical_information ALTER COLUMN statistical_information_id SET DEFAULT nextval('work.t_statistical_information_statistical_information_id_seq'::regclass);


--
-- Name: t_sys_data sys_data_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_sys_data ALTER COLUMN sys_data_id SET DEFAULT nextval('work.t_sys_data_sys_data_id_seq'::regclass);


--
-- Name: t_technical_data technical_data_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_technical_data ALTER COLUMN technical_data_id SET DEFAULT nextval('work.t_technical_data_technical_data_id_seq'::regclass);


--
-- Name: t_term_of_grant term_of_grant_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_term_of_grant ALTER COLUMN term_of_grant_id SET DEFAULT nextval('work.t_term_of_grant_term_of_grant_id_seq'::regclass);


--
-- Name: t_us_sir_flag us_sir_flag_id; Type: DEFAULT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_us_sir_flag ALTER COLUMN us_sir_flag_id SET DEFAULT nextval('work.t_us_sir_flag_us_sir_flag_id_seq'::regclass);


--
-- Name: t_sys_data pkey_sys_data_id; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_sys_data
    ADD CONSTRAINT pkey_sys_data_id PRIMARY KEY (sys_data_id);


--
-- Name: t_abstract t_abstract_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_abstract
    ADD CONSTRAINT t_abstract_pkey PRIMARY KEY (abstract_id);


--
-- Name: t_amended_claims t_amended_claims_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_amended_claims
    ADD CONSTRAINT t_amended_claims_pkey PRIMARY KEY (amended_claims_id);


--
-- Name: t_application_reference t_application_reference_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_application_reference
    ADD CONSTRAINT t_application_reference_pkey PRIMARY KEY (application_reference_id);


--
-- Name: t_attachments_external t_attachments_external_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_attachments_external
    ADD CONSTRAINT t_attachments_external_pkey PRIMARY KEY (attachments_external_id);


--
-- Name: t_citations t_citations_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_citations
    ADD CONSTRAINT t_citations_pkey PRIMARY KEY (citation_id);


--
-- Name: t_claims t_claims_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_claims
    ADD CONSTRAINT t_claims_pkey PRIMARY KEY (claims_id);


--
-- Name: t_classification_ecla t_classification_ecla_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_classification_ecla
    ADD CONSTRAINT t_classification_ecla_pkey PRIMARY KEY (classification_ecla_id);


--
-- Name: t_classification_ipc t_classification_ipc_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_classification_ipc
    ADD CONSTRAINT t_classification_ipc_pkey PRIMARY KEY (classification_ipc_id);


--
-- Name: t_classification_locarno t_classification_locarno_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_classification_locarno
    ADD CONSTRAINT t_classification_locarno_pkey PRIMARY KEY (classification_locarno_id);


--
-- Name: t_classification_national t_classification_national_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_classification_national
    ADD CONSTRAINT t_classification_national_pkey PRIMARY KEY (classification_national_id);


--
-- Name: t_classifications_cpc t_classifications_cpc_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_classifications_cpc
    ADD CONSTRAINT t_classifications_cpc_pkey PRIMARY KEY (classifications_cpc_id);


--
-- Name: t_classifications_ipcr t_classifications_ipcr_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_classifications_ipcr
    ADD CONSTRAINT t_classifications_ipcr_pkey PRIMARY KEY (classifications_ipcr_id);


--
-- Name: t_dates_of_public_availability t_dates_of_public_availability_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_dates_of_public_availability
    ADD CONSTRAINT t_dates_of_public_availability_pkey PRIMARY KEY (dates_of_public_availability_id);


--
-- Name: t_description t_description_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_description
    ADD CONSTRAINT t_description_pkey PRIMARY KEY (description_id);


--
-- Name: t_designated_states t_designated_states_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_designated_states
    ADD CONSTRAINT t_designated_states_pkey PRIMARY KEY (designated_states);


--
-- Name: t_drawings t_drawings_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_drawings
    ADD CONSTRAINT t_drawings_pkey PRIMARY KEY (drawings_id);


--
-- Name: t_f_term_info t_f_term_info_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_f_term_info
    ADD CONSTRAINT t_f_term_info_pkey PRIMARY KEY (f_term_info_id);


--
-- Name: t_field_of_search t_field_of_search_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_field_of_search
    ADD CONSTRAINT t_field_of_search_pkey PRIMARY KEY (field_of_search_id);


--
-- Name: t_figures t_figures_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_figures
    ADD CONSTRAINT t_figures_pkey PRIMARY KEY (figure_id);


--
-- Name: t_ifi_annotated_data t_ifi_annotated_data_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_ifi_annotated_data
    ADD CONSTRAINT t_ifi_annotated_data_pkey PRIMARY KEY (ifi_annotated_data_id);


--
-- Name: t_ifi_integrated_content t_ifi_integrated_content_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_ifi_integrated_content
    ADD CONSTRAINT t_ifi_integrated_content_pkey PRIMARY KEY (ifi_integrated_content_id);


--
-- Name: t_international_convention_data t_international_convention_data_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_international_convention_data
    ADD CONSTRAINT t_international_convention_data_pkey PRIMARY KEY (international_convention_data);


--
-- Name: t_invention_title t_invention_title_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_invention_title
    ADD CONSTRAINT t_invention_title_pkey PRIMARY KEY (invention_title_id);


--
-- Name: t_keywords t_keywords_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_keywords
    ADD CONSTRAINT t_keywords_pkey PRIMARY KEY (keywords_id);


--
-- Name: t_legal_status t_legal_status_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_legal_status
    ADD CONSTRAINT t_legal_status_pkey PRIMARY KEY (legal_status_id);


--
-- Name: t_office_specific_data t_office_specific_data_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_office_specific_data
    ADD CONSTRAINT t_office_specific_data_pkey PRIMARY KEY (office_specific_data_id);


--
-- Name: t_parties t_parties_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_parties
    ADD CONSTRAINT t_parties_pkey PRIMARY KEY (parties_id);


--
-- Name: t_patent_document_values t_patent_document_values_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_patent_document_values
    ADD CONSTRAINT t_patent_document_values_pkey PRIMARY KEY (patent_document_value_id);


--
-- Name: t_priority_claims t_priority_claims_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_priority_claims
    ADD CONSTRAINT t_priority_claims_pkey PRIMARY KEY (priority_claims_id);


--
-- Name: t_publication_reference t_publication_reference_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_publication_reference
    ADD CONSTRAINT t_publication_reference_pkey PRIMARY KEY (publication_reference_id);


--
-- Name: t_related_documents t_related_documents_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_related_documents
    ADD CONSTRAINT t_related_documents_pkey PRIMARY KEY (related_documents_id);


--
-- Name: t_revision_history t_revision_history_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_revision_history
    ADD CONSTRAINT t_revision_history_pkey PRIMARY KEY (revision_history_id);


--
-- Name: t_rule_47_flag t_rule_47_flag_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_rule_47_flag
    ADD CONSTRAINT t_rule_47_flag_pkey PRIMARY KEY (rule_47_flag_id);


--
-- Name: t_search_report_data t_search_report_data_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_search_report_data
    ADD CONSTRAINT t_search_report_data_pkey PRIMARY KEY (search_report_id);


--
-- Name: t_statistical_information t_statistical_information_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_statistical_information
    ADD CONSTRAINT t_statistical_information_pkey PRIMARY KEY (statistical_information_id);


--
-- Name: t_technical_data t_technical_data_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_technical_data
    ADD CONSTRAINT t_technical_data_pkey PRIMARY KEY (technical_data_id);


--
-- Name: t_term_of_grant t_term_of_grant_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_term_of_grant
    ADD CONSTRAINT t_term_of_grant_pkey PRIMARY KEY (term_of_grant_id);


--
-- Name: t_us_sir_flag t_us_sir_flag_pkey; Type: CONSTRAINT; Schema: work; Owner: -
--

ALTER TABLE ONLY work.t_us_sir_flag
    ADD CONSTRAINT t_us_sir_flag_pkey PRIMARY KEY (us_sir_flag_id);


--
-- Name: idx_country_published; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_country_published ON work.t_patent_document_values USING btree (country, published);


--
-- Name: idx_patent_document_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_patent_document_ucid ON work.t_patent_document_values USING btree (ucid);


--
-- Name: idx_patent_document_values_country; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_patent_document_values_country ON work.t_patent_document_values USING btree (country);


--
-- Name: idx_t_abstract_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_abstract_cmp ON work.t_abstract USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_abstract_publication_id; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_abstract_publication_id ON work.t_abstract USING btree (publication_id);


--
-- Name: idx_t_amended_claims_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_amended_claims_cmp ON work.t_amended_claims USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_application_reference_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_application_reference_cmp ON work.t_application_reference USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_attachments_external_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_attachments_external_cmp ON work.t_attachments_external USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_citation_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_citation_cmp ON work.t_citations USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_claims_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_claims_cmp ON work.t_claims USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_classification_ecla_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_classification_ecla_cmp ON work.t_classification_ecla USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_classification_ipc_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_classification_ipc_cmp ON work.t_classification_ipc USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_classification_locarno_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_classification_locarno_cmp ON work.t_classification_locarno USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_classification_national_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_classification_national_cmp ON work.t_classification_national USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_classifications_cpc_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_classifications_cpc_cmp ON work.t_classifications_cpc USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_classifications_ipcr_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_classifications_ipcr_cmp ON work.t_classifications_ipcr USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_dates_of_public_availability_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_dates_of_public_availability_cmp ON work.t_dates_of_public_availability USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_description_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_description_cmp ON work.t_description USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_designated_states_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_designated_states_cmp ON work.t_designated_states USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_drawings_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_drawings_cmp ON work.t_drawings USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_f_term_info_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_f_term_info_cmp ON work.t_f_term_info USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_field_of_search_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_field_of_search_cmp ON work.t_field_of_search USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_figure_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_figure_cmp ON work.t_figures USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_ifi_annotated_data_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_ifi_annotated_data_cmp ON work.t_ifi_annotated_data USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_ifi_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_ifi_cmp ON work.t_ifi_integrated_content USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_international_convention_data_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_international_convention_data_cmp ON work.t_international_convention_data USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_invention_title_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_invention_title_cmp ON work.t_invention_title USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_keywords_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_keywords_cmp ON work.t_keywords USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_legal_status_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_legal_status_cmp ON work.t_legal_status USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_office_specific_data_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_office_specific_data_cmp ON work.t_office_specific_data USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_parties_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_parties_cmp ON work.t_parties USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_patent_document_values_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_patent_document_values_cmp ON work.t_patent_document_values USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_priority_claims_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_priority_claims_cmp ON work.t_priority_claims USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_publication_reference_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_publication_reference_cmp ON work.t_publication_reference USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_related_documents_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_related_documents_cmp ON work.t_related_documents USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_revision_history_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_revision_history_cmp ON work.t_revision_history USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_rule_47_flag_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_rule_47_flag_cmp ON work.t_rule_47_flag USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_search_report_data_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_search_report_data_cmp ON work.t_search_report_data USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_statistical_information_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_statistical_information_cmp ON work.t_statistical_information USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_technical_data_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_technical_data_cmp ON work.t_technical_data USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_term_of_grant_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_term_of_grant_cmp ON work.t_term_of_grant USING btree (publication_id, modified_load_id);


--
-- Name: idx_t_us_sir_flag_cmp; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_t_us_sir_flag_cmp ON work.t_us_sir_flag USING btree (publication_id, modified_load_id);


--
-- Name: idx_work_t_abstract_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_abstract_ucid ON work.t_abstract USING btree (ucid);


--
-- Name: idx_work_t_amended_claims_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_amended_claims_ucid ON work.t_amended_claims USING btree (ucid);


--
-- Name: idx_work_t_application_reference_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_application_reference_ucid ON work.t_application_reference USING btree (ucid);


--
-- Name: idx_work_t_attachments_external_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_attachments_external_ucid ON work.t_attachments_external USING btree (ucid);


--
-- Name: idx_work_t_citations_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_citations_ucid ON work.t_citations USING btree (ucid);


--
-- Name: idx_work_t_claims_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_claims_ucid ON work.t_claims USING btree (ucid);


--
-- Name: idx_work_t_classification_ecla_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_classification_ecla_ucid ON work.t_classification_ecla USING btree (ucid);


--
-- Name: idx_work_t_classification_ipc_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_classification_ipc_ucid ON work.t_classification_ipc USING btree (ucid);


--
-- Name: idx_work_t_classification_locarno_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_classification_locarno_ucid ON work.t_classification_locarno USING btree (ucid);


--
-- Name: idx_work_t_classification_national_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_classification_national_ucid ON work.t_classification_national USING btree (ucid);


--
-- Name: idx_work_t_classifications_cpc_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_classifications_cpc_ucid ON work.t_classifications_cpc USING btree (ucid);


--
-- Name: idx_work_t_classifications_ipcr_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_classifications_ipcr_ucid ON work.t_classifications_ipcr USING btree (ucid);


--
-- Name: idx_work_t_dates_of_public_availability_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_dates_of_public_availability_ucid ON work.t_dates_of_public_availability USING btree (ucid);


--
-- Name: idx_work_t_description_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_description_ucid ON work.t_description USING btree (ucid);


--
-- Name: idx_work_t_designated_states_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_designated_states_ucid ON work.t_designated_states USING btree (ucid);


--
-- Name: idx_work_t_drawings_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_drawings_ucid ON work.t_drawings USING btree (ucid);


--
-- Name: idx_work_t_f_term_info_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_f_term_info_ucid ON work.t_f_term_info USING btree (ucid);


--
-- Name: idx_work_t_field_of_search_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_field_of_search_ucid ON work.t_field_of_search USING btree (ucid);


--
-- Name: idx_work_t_figures_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_figures_ucid ON work.t_figures USING btree (ucid);


--
-- Name: idx_work_t_ifi_annotated_data_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_ifi_annotated_data_ucid ON work.t_ifi_annotated_data USING btree (ucid);


--
-- Name: idx_work_t_ifi_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_ifi_ucid ON work.t_ifi_integrated_content USING btree (ucid);


--
-- Name: idx_work_t_international_convention_data_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_international_convention_data_ucid ON work.t_international_convention_data USING btree (ucid);


--
-- Name: idx_work_t_invention_title_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_invention_title_ucid ON work.t_invention_title USING btree (ucid);


--
-- Name: idx_work_t_keywords_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_keywords_ucid ON work.t_keywords USING btree (ucid);


--
-- Name: idx_work_t_legal_status_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_legal_status_ucid ON work.t_legal_status USING btree (ucid);


--
-- Name: idx_work_t_office_specific_data_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_office_specific_data_ucid ON work.t_office_specific_data USING btree (ucid);


--
-- Name: idx_work_t_parties_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_parties_ucid ON work.t_parties USING btree (ucid);


--
-- Name: idx_work_t_priority_claims_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_priority_claims_ucid ON work.t_priority_claims USING btree (ucid);


--
-- Name: idx_work_t_publication_reference_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_publication_reference_ucid ON work.t_publication_reference USING btree (ucid);


--
-- Name: idx_work_t_related_documents_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_related_documents_ucid ON work.t_related_documents USING btree (ucid);


--
-- Name: idx_work_t_revision_history_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_revision_history_ucid ON work.t_revision_history USING btree (ucid);


--
-- Name: idx_work_t_rule_47_flag_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_rule_47_flag_ucid ON work.t_rule_47_flag USING btree (ucid);


--
-- Name: idx_work_t_search_report_data_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_search_report_data_ucid ON work.t_search_report_data USING btree (ucid);


--
-- Name: idx_work_t_statistical_information_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_statistical_information_ucid ON work.t_statistical_information USING btree (ucid);


--
-- Name: idx_work_t_technical_data_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_technical_data_ucid ON work.t_technical_data USING btree (ucid);


--
-- Name: idx_work_t_term_of_grant_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_term_of_grant_ucid ON work.t_term_of_grant USING btree (ucid);


--
-- Name: idx_work_t_us_sir_flag_ucid; Type: INDEX; Schema: work; Owner: -
--

CREATE INDEX idx_work_t_us_sir_flag_ucid ON work.t_us_sir_flag USING btree (ucid);


--
-- PostgreSQL database dump complete
--

