DROP SCHEMA cdws CASCADE;

CREATE SCHEMA cdws;

/* FOR OLDER INSTALLATIONS WITHOUT xml.f_id2ucid */
CREATE OR REPLACE FUNCTION xml.f_id2ucid(
        integer)
    RETURNS text
    LANGUAGE 'sql'
    COST 100
    IMMUTABLE
AS $BODY$
  select ucid from xml.t_patent_document_values where publication_id=$1;
$BODY$;

CREATE TABLE cdws.t_cited_documents (
  id serial primary key,
  publication_id integer NOT NULL,
  cited_document_id integer NOT NULL,
  source character varying(8) NOT NULL,
  is_app boolean NOT NULL,
  load_id integer NOT NULL
);

CREATE INDEX idx_t_cited_documents_publication_id ON cdws.t_cited_documents USING btree (publication_id);
CREATE INDEX idx_t_cited_documents_cited_document_id ON cdws.t_cited_documents USING btree (cited_document_id);
CREATE INDEX idx_t_cited_documents_source ON cdws.t_cited_documents USING btree (source);
CREATE INDEX idx_t_cited_documents_is_app ON cdws.t_cited_documents USING btree (is_app);
CREATE INDEX idx_t_cited_documents_load_id ON cdws.t_cited_documents USING btree (load_id);

CREATE TABLE cdws.t_applications (
  application_id serial primary key,
  application_ucid character varying(32) UNIQUE NOT NULL,
  filed date
);

CREATE INDEX idx_t_applications_filed ON cdws.t_applications USING btree (filed);

CREATE TABLE cdws.t_priority_documents (
  priority_id serial primary key,
  publication_id integer NOT NULL,
  application_id integer NOT NULL,
  app_type character(1) NOT NULL,
  link character(1),
  load_id integer NOT NULL
);

CREATE INDEX idx_t_priority_documents_publication_id ON cdws.t_priority_documents USING btree (publication_id);
CREATE INDEX idx_t_priority_documents_application_id ON cdws.t_priority_documents USING btree (application_id);
CREATE INDEX idx_t_priority_documents_app_type ON cdws.t_priority_documents USING btree (app_type);
CREATE INDEX idx_t_priority_documents_load_id ON cdws.t_priority_documents USING btree (load_id);




--
-- Name: f_ifi_names(integer); Type: FUNCTION; Schema: cdws; Owner: -
--
CREATE FUNCTION cdws.f_ifi_names(integer) RETURNS TABLE(ifi_name_original text, ifi_name_original_country character varying, ifi_name_current text, ifi_name_current_country character varying)
    LANGUAGE plpgsql
    AS $_$
declare v_content xml;
        v_node xml;
begin

-- example usage:
-- select * from cdws.f_ifi_names( xml.f_ucid2id('US-9843920-B2') );
-- select * from cdws.f_ifi_names( xml.f_ucid2id('EP-0700000-B1') );
  select x.content into v_content
    from xml.t_ifi_integrated_content as x where x.publication_id=$1;
  if not found then
    return;
  end if;

  foreach v_node in array
    ( select xml.f_getElementsByTagName('ifi-standardized-name', v_content ) ) loop
    select xml.f_getAttribute('country', v_node) into ifi_name_original_country;
    select xml.f_textContent('./addressbook/name', v_node) into ifi_name_original;
  end loop;

  foreach v_node in array
    ( select xml.f_getElementsByTagName('ifi-standardized-name-probable', v_content ) ) loop
    select xml.f_getAttribute('country', v_node) into ifi_name_original_country;
    select xml.f_textContent('./addressbook/name', v_node) into ifi_name_original;
  end loop;

  foreach v_node in array
    ( select xml.f_getElementsByTagName('ifi-standardized-name-current', v_content ) ) loop
    select xml.f_getAttribute('country', v_node) into ifi_name_current_country;
    select xml.f_textContent('./addressbook/name', v_node) into ifi_name_current;
  end loop;
  return next;
  return;

end;
$_$;

--
-- Name: f_citations_backward(integer); Type: FUNCTION; Schema: cdws; Owner: -
--

CREATE FUNCTION cdws.f_citations_backward(integer) RETURNS TABLE(ucid text, source text)
    LANGUAGE sql STABLE
    AS $_$
-- select * from cdws.f_citations_backwards( xml.f_ucid2id('US-5551212-A') );
  SELECT xml.f_id2ucid(cited_document_id), source
  FROM cdws.t_cited_documents
  WHERE publication_id = $1
    AND is_app IS FALSE;
$_$;


--
-- Name: f_citations_forward(integer); Type: FUNCTION; Schema: cdws; Owner: -
--

CREATE FUNCTION cdws.f_citations_forward(integer) RETURNS TABLE(ucid text, source text)
    LANGUAGE sql STABLE
    AS $_$

-- select * from cdws.f_citations_forward( xml.f_ucid2id('US-5551212-A') );
  SELECT xml.f_id2ucid(publication_id), source
  FROM cdws.t_cited_documents
  WHERE cited_document_id = $1
    AND is_app IS FALSE;
$_$;


--
-- Name: f_family_simple(integer); Type: FUNCTION; Schema: cdws; Owner: -
--
CREATE FUNCTION cdws.f_family_simple(v_pub_id integer) RETURNS TABLE(ucid character varying, family_id integer)
    LANGUAGE plpgsql STRICT
    AS $$
DECLARE
  v_ucid varchar(64);
BEGIN

  select a.ucid into v_ucid from xml.t_patent_document_values as a where publication_id = v_pub_id;
  if not found then
    return;
  end if;

  return query
    select a.ucid, a.family_id
     from xml.t_patent_document_values as a
     where a.family_id in (
       select b.family_id
       from xml.t_patent_document_values as b
       where b.publication_id=v_pub_id
         and b.family_id != -1
         and b.deleted_load_id is null
     ) and a.ucid != v_ucid
       and a.deleted_load_id is null
     order by a.ucid asc;
END;
$$;

--
-- Name: f_family_extended(integer, boolean); Type: FUNCTION; Schema: cdws; Owner: -
--
CREATE FUNCTION cdws.f_family_extended(v_pub_id integer, v_include_apps boolean DEFAULT false) RETURNS TABLE(publication_id integer, ucid character varying, level integer)
    LANGUAGE plpgsql STRICT
    SET client_min_messages TO 'warning'
    AS $$
DECLARE
  v_level INTEGER := 0;
BEGIN

  -- EPO extended family: Patent applications that are members of an extended
  -- patent family will have at least one priority in common with at least one
  -- of the other members – either directly or indirectly.

  CREATE TEMPORARY TABLE IF NOT EXISTS t_tmp_family_lookup (
    publication_id INTEGER NOT NULL,
    application_id INTEGER NOT NULL,
    level INTEGER NOT NULL
  ) ON COMMIT DROP;
  TRUNCATE TABLE t_tmp_family_lookup;

  -- for the specified publication_id, insert all of the application_ids
  -- associated with that publication into the temp table
  IF v_include_apps THEN
    INSERT INTO t_tmp_family_lookup (publication_id, application_id, level)
    SELECT pd.publication_id, pd.application_id, v_level
    FROM cdws.t_priority_documents AS pd
    WHERE pd.publication_id = v_pub_id;
  ELSE
    INSERT INTO t_tmp_family_lookup (publication_id, application_id, level)
    SELECT pd.publication_id, pd.application_id, v_level
    FROM cdws.t_priority_documents AS pd
    WHERE pd.publication_id = v_pub_id
      AND pd.app_type = 'P';
  END IF;

  -- for records having no priorities insert an application_id of -1, no family
  -- members will be found, but we will return the original publication
  IF NOT FOUND THEN
    INSERT INTO t_tmp_family_lookup (publication_id, application_id, level)
    SELECT v_pub_id, -1, v_level;
  END IF;

  LOOP
    v_level := v_level + 1;

    -- next grab all of the publication_ids associated with any of the
    -- application_ids in the temp table, at each step of the way if a
    -- publication exists in the temp table all of its applications exist
    -- as well
    IF v_include_apps THEN
      -- the new table includes docdb applications and priorities, if the
      -- v_include_apps flag is set then both will be included when creating
      -- the extended family
      WITH pubs AS (
        WITH apps AS (
          SELECT DISTINCT application_id
          FROM t_tmp_family_lookup
        )
        SELECT pd2.publication_id, pd2.application_id
        FROM apps
          INNER JOIN cdws.t_priority_documents AS pd1
            ON apps.application_id = pd1.application_id
          INNER JOIN cdws.t_priority_documents AS pd2
            ON pd1.publication_id = pd2.publication_id
        WHERE NOT EXISTS (
          SELECT 1
          FROM t_tmp_family_lookup AS tmp
          WHERE tmp.publication_id = pd1.publication_id
        )
      )
      -- for all of the publication_ids gathered above, insert into the temp
      -- table all application_ids associated with those publications
      INSERT INTO t_tmp_family_lookup (publication_id, application_id, level)
      SELECT DISTINCT pubs.publication_id, pubs.application_id, v_level
      FROM pubs;
    ELSE
      -- if the v_include_apps flag is not set then only priorities
      -- will be included (app_type P)
      WITH pubs AS (
        WITH apps AS (
          SELECT DISTINCT application_id
          FROM t_tmp_family_lookup
        )
        SELECT pd2.publication_id, pd2.application_id
        FROM apps
          INNER JOIN cdws.t_priority_documents AS pd1
            ON apps.application_id = pd1.application_id
          INNER JOIN cdws.t_priority_documents AS pd2
            ON pd1.publication_id = pd2.publication_id
        WHERE 
          pd1.app_type = 'P'
          AND pd2.app_type = 'P'
          AND NOT EXISTS (
            SELECT 1
            FROM t_tmp_family_lookup AS tmp
            WHERE tmp.publication_id = pd1.publication_id
          )
      )
      -- for all of the publication_ids gathered above, insert into the temp
      -- table all application_ids associated with those publications
      INSERT INTO t_tmp_family_lookup (publication_id, application_id, level)
      SELECT DISTINCT pubs.publication_id, pubs.application_id, v_level
      FROM pubs;
    END IF;

    IF NOT FOUND THEN
      EXIT;
    END IF;
    
  END LOOP;

  RETURN QUERY
    SELECT
      DISTINCT tmp.publication_id, p.ucid, tmp.level
    FROM
      t_tmp_family_lookup AS tmp
        INNER JOIN
      xml.t_patent_document_values AS p
        ON tmp.publication_id = p.publication_id
    ORDER BY
      tmp.level, p.ucid;
END;

$$;


--
-- Name: f_family_meta(integer); Type: FUNCTION; Schema: cdws; Owner: -
--

CREATE FUNCTION cdws.f_family_meta(integer) RETURNS TABLE(family_id integer, ucid text, published integer, anucid text, filed integer, title text, ifi_status text, ifi_anticipated_expiration integer, ifi_adjusted_expiration integer, epo_legal_status_xml xml)
    LANGUAGE plpgsql
    AS $_$
declare
  v_family_id alias for $1;
  --v_ucid alias for $1;
  v_rec record;
  v_app_rec record;
  v_ls_rec record;
  v_content xml;
  v_node xml;
  v_name text;
  v_has_ucid boolean;
  v_country text;
  v_doc_number text;
  v_kind text;
  v_filed integer;
  v_pub_lang text;
  v_ttl_lang text;
  v_ttl_ord integer;
  v_ttl_load_source text;
begin

/*
select family_id from xml.t_patent_document_values where ucid='US-5551212-A'
  select * from fws.f_family_meta( 6413406 );
  select * from fws.f_family_meta( 23153058 );
  select * from rdb.f_applications( xml.f_ucid2id( 'US-5551212-A' ) ) where fmt='epo';
*/

  -- raise notice '%, %, %, %, %, %',v_family_id, v_ctry, v_ucid, v_application_ucid, v_origin, v_ft;

  -- get entire family    
  for v_rec in
    select a.family_id, a.publication_id, a.ucid, to_char(a.published, 'YYYYMMDD') as published, a.lang
    from xml.t_patent_document_values as a
    where a.family_id = v_family_id
      and a.deleted_load_id is null
      and status not in ('d', 'deleted')
      and a.withdraw != true
    order by a.ucid asc
  loop

    select v_rec.family_id into family_id;
    select v_rec.ucid into ucid;
    select v_rec.published into published;
    select false into v_has_ucid;

    -- application data
    select content into v_content from xml.t_application_reference t where t.publication_id=v_rec.publication_id;
    if found then

      select xml.f_getAttribute('ucid', v_content) into anucid;
      if( anucid is not null ) then
        select true into v_has_ucid;
      end if;

      foreach v_node in array
        ( select xml.f_findNodes('//document-id', v_content) ) loop

        if v_country is null then select xml.f_textContent( './country', v_node ) into v_country; end if;
        if v_doc_number is null then select xml.f_textContent( './doc-number', v_node ) into v_doc_number; end if;
        if v_kind is null then select xml.f_textContent( './kind', v_node ) into v_kind; end if;
        if filed is null then select xml.f_textContent( './date', v_node ) into filed; end if;

        if( v_has_ucid = false ) then
          select v_country || '-' || v_doc_number into anucid;
        end if;
        if( v_kind = 'D' ) then
          select v_country || '-' || v_doc_number || '-A' into anucid;
        end if;
      end loop;

    end if;

    -- legal status
    select content into epo_legal_status_xml from xml.t_legal_status t where t.publication_id=v_rec.publication_id;

    select null into ifi_status; -- clear variable
    select c.content from xml.t_ifi_integrated_content as c
      into v_content
    where c.publication_id=v_rec.publication_id;
    if found then
      select xml.f_findNode( '//ifi-patent-status', v_content ) into v_node;
      if v_node is not null then
        select xml.f_getAttribute( 'anticipated-expiration', v_node ) into ifi_anticipated_expiration;
        select xml.f_getAttribute( 'adjusted-expiration', v_node ) into ifi_adjusted_expiration;
      end if;
      select xml.f_findvalue( '//ifi-patent-status-description', v_content )
        into ifi_status;
    end if;

    select t1.lang, xml.f_getAttribute('lang', t2.content),
           case when xml.f_getAttribute('lang', t2.content) = 'EN'
                       and
                     xml.f_getAttribute('load-source', t2.content) = 'patent-office' then 0
                when xml.f_getAttribute('lang', t2.content) = 'EN' then 1
                when xml.f_getAttribute('lang', t2.content) = t1.lang then 2
                when xml.f_getAttribute('lang', t2.content) = 'DE' then 3
                when xml.f_getAttribute('lang', t2.content) = 'FR' then 4
                else 5
           end as ttl_ord,
           xml.f_getAttribute('load-source', t2.content) as ttl_load_source,
           xml.f_textContent('.', t2.content) as x
      into v_pub_lang, v_ttl_lang, v_ttl_ord, v_ttl_load_source, title
    from xml.t_patent_document_values t1
      inner join xml.t_invention_title t2
        on (t1.publication_id=t2.publication_id)
    where t1.publication_id=v_rec.publication_id
    order by ttl_ord limit 1;
    
    return next;

  end loop;
  return;
end;

$_$;



--
-- Name: f_text_bibliographic_data(integer, text); Type: FUNCTION; Schema: cdws; Owner: -
--

CREATE FUNCTION cdws.f_text_bibliographic_data(integer, text) RETURNS xml
    LANGUAGE plpgsql
    AS $_$
declare
  v_pub_id alias for $1;
  v_useropt alias for $2;
begin
  -- select cdws.f_text_default( xml.f_ucid2id('CN-102837504-A'), '');
  -- select cdws.f_text_default( 127422754, '');

  return (
    select xmlelement(name "patent-document",
               xmlattributes(modified_load_id as "file-reference-id",
                             v_pub_id as "mxw-id",
                             ucid as ucid,
                             lang as lang,
                             country as country,
                             doc_number as "doc-number",
                             kind as kind,
                             to_char(published, 'YYYYMMDD') as "date",
                             to_char(produced, 'YYYYMMDD') as "date-produced",
                             family_id as "family-id",
                             status as "status",
                             case when withdraw=true then 'yes' end as "withdrawn"),
             xmlelement(name "bibliographic-data",
              (select content from xml.t_publication_reference where publication_id=v_pub_id ),
              (select content from xml.t_us_sir_flag where publication_id=v_pub_id ),
              (select content from xml.t_application_reference where publication_id=v_pub_id ),
              (select content from xml.t_priority_claims where publication_id=v_pub_id ),
              (select xmlagg(content) from xml.t_dates_of_public_availability where publication_id=v_pub_id ),
              (select content from xml.t_rule_47_flag where publication_id=v_pub_id ),
              (select content from xml.t_term_of_grant where publication_id=v_pub_id ),
              (select xmlelement(name "technical-data",
                (select xmlagg(content) from xml.t_classification_ipc where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_classification_locarno where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_classifications_ipcr where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_classification_national where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_classification_ecla where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_classifications_cpc where publication_id=$1),
                (select xmlagg(content) from xml.t_f_term_info where publication_id=v_pub_id),
                -- sub function for just titles
                (select xml.f_invention_title(v_pub_id, v_useropt)),
                (select xmlagg(content) from xml.t_citations where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_figures where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_field_of_search where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_statistical_information where publication_id=v_pub_id) )
              ),
              (select content from xml.t_related_documents where publication_id=v_pub_id ),
              (select content from xml.t_parties where publication_id=v_pub_id ),
              (select content from xml.t_international_convention_data where publication_id=v_pub_id ),
              (select content from xml.t_designated_states where publication_id=v_pub_id ),
              (select content from xml.t_office_specific_data where publication_id=v_pub_id ),
              (select content from xml.t_ifi_integrated_content where publication_id=v_pub_id ),
              (select content from xml.t_ifi_annotated_data where publication_id=v_pub_id )
            ),  -- end bibliographic-data
            (select xml.f_copyright( v_pub_id, v_useropt ) )
          )
    from xml.t_patent_document_values
    where publication_id=v_pub_id
  );
end;
$_$;


--
-- Name: f_text_default(integer, text); Type: FUNCTION; Schema: cdws; Owner: -
--

CREATE FUNCTION cdws.f_text_default(integer, text) RETURNS xml
    LANGUAGE plpgsql
    AS $_$
declare
  v_pub_id alias for $1;
  v_useropt alias for $2;
begin
  -- select cdws.f_text_default( xml.f_ucid2id('CN-102837504-A'), '');
  -- select cdws.f_text_default( 127422754, '');

  return (
    select xmlelement(name "patent-document",
               xmlattributes(modified_load_id as "file-reference-id",
                             v_pub_id as "mxw-id",
                             ucid as ucid,
                             lang as lang,
                             country as country,
                             doc_number as "doc-number",
                             kind as kind,
                             to_char(published, 'YYYYMMDD') as "date",
                             to_char(produced, 'YYYYMMDD') as "date-produced",
                             family_id as "family-id",
                             status as "status",
                             case when withdraw=true then 'yes' end as "withdrawn"),
             xmlelement(name "bibliographic-data",
              (select content from xml.t_publication_reference where publication_id=v_pub_id ),
              (select content from xml.t_us_sir_flag where publication_id=v_pub_id ),
              (select content from xml.t_application_reference where publication_id=v_pub_id ),
              (select content from xml.t_priority_claims where publication_id=v_pub_id ),
              (select xmlagg(content) from xml.t_dates_of_public_availability where publication_id=v_pub_id ),
              (select content from xml.t_rule_47_flag where publication_id=v_pub_id ),
              (select content from xml.t_term_of_grant where publication_id=v_pub_id ),
              (select xmlelement(name "technical-data",
                (select xmlagg(content) from xml.t_classification_ipc where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_classification_locarno where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_classifications_ipcr where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_classification_national where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_classification_ecla where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_classifications_cpc where publication_id=$1),
                (select xmlagg(content) from xml.t_f_term_info where publication_id=v_pub_id),
                -- sub function for just titles
                (select xml.f_invention_title(v_pub_id, v_useropt)),
                (select xmlagg(content) from xml.t_citations where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_figures where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_field_of_search where publication_id=v_pub_id),
                (select xmlagg(content) from xml.t_statistical_information where publication_id=v_pub_id) )
              ),
              (select content from xml.t_related_documents where publication_id=v_pub_id ),
              (select content from xml.t_parties where publication_id=v_pub_id ),
              (select content from xml.t_international_convention_data where publication_id=v_pub_id ),
              (select content from xml.t_designated_states where publication_id=v_pub_id ),
              (select content from xml.t_office_specific_data where publication_id=v_pub_id ),
              (select content from xml.t_ifi_integrated_content where publication_id=v_pub_id ),
              (select content from xml.t_ifi_annotated_data where publication_id=v_pub_id )
            ) , -- end bibliographic-data
            (select xml.f_abstract(v_pub_id, v_useropt)),
            (select xml.f_description(v_pub_id, v_useropt)),
            (select xml.f_claims(v_pub_id, v_useropt)),
            (select xmlagg(content) from xml.t_amended_claims where publication_id=v_pub_id ),
            (select content from xml.t_drawings where publication_id=v_pub_id ),
            -- ALPA-2386
            (select content from xml.t_attachments_external where publication_id=v_pub_id ),
            (select xmlagg(content) from xml.t_search_report_data where publication_id=v_pub_id ),
            (select xmlagg(content) from xml.t_keywords where publication_id=v_pub_id ),
            (select xmlagg(content) from xml.t_legal_status where publication_id=v_pub_id ),
            (select xmlagg(content) from xml.t_revision_history where publication_id=v_pub_id ),
            (select xml.f_copyright( v_pub_id, v_useropt ) )
          )
    from xml.t_patent_document_values
    where publication_id=v_pub_id
  );
end;
$_$;


--
-- Name: f_text_tac(integer, text); Type: FUNCTION; Schema: cdws; Owner: -
--

CREATE FUNCTION cdws.f_text_tac(integer, text) RETURNS xml
    LANGUAGE plpgsql
    AS $_$
 declare
   v_pub_id alias for $1;
   v_useropt alias for $2;
 begin
   -- select cdws.f_text_default( xml.f_ucid2id('CN-102837504-A'), '');
   -- select cdws.f_text_default( 127422754, '');

   return (
     select xmlelement(name "patent-document",
                xmlattributes(modified_load_id as "file-reference-id",
                              v_pub_id as "mxw-id",
                              ucid as ucid,
                              lang as lang,
                              country as country,
                              doc_number as "doc-number",
                              kind as kind,
                              to_char(published, 'YYYYMMDD') as "date",
                              to_char(produced, 'YYYYMMDD') as "date-produced",
                              family_id as "family-id",
                              status as "status",
                              case when withdraw=true then 'yes' end as "withdrawn"),
              xmlelement(name "bibliographic-data",
               (select content from xml.t_publication_reference where publication_id=v_pub_id ),
               (select content from xml.t_application_reference where publication_id=v_pub_id ),
               (select xmlelement(name "technical-data",
                 -- sub function for just titles
                 (select xml.f_invention_title(v_pub_id, v_useropt))
               ) )
             ),  -- end bibliographic-data
             (select xml.f_abstract(v_pub_id, v_useropt)),
             (select xml.f_claims(v_pub_id, v_useropt)),
             (select xml.f_copyright( v_pub_id, v_useropt ) )
          )
     from xml.t_patent_document_values
     where publication_id=v_pub_id
   );
 end;
 $_$;


--
-- Name: f_update_cited_documents(integer); Type: FUNCTION; Schema: cdws; Owner: -
--
CREATE FUNCTION cdws.f_update_cited_documents(v_load_id integer) RETURNS void
    LANGUAGE plpgsql
    AS $$

DECLARE
  v_total integer;
BEGIN

  CREATE TEMPORARY TABLE IF NOT EXISTS t_tmp_cited_documents (
    publication_id integer NOT NULL,
    cited_ucid text NOT NULL,
    cited_document_id integer,
    source varchar(8) NOT NULL,
    is_app boolean NOT NULL,
    load_id integer NOT NULL
  ) ON COMMIT DROP;
  TRUNCATE TABLE t_tmp_cited_documents;

  -- first pull out each patcit node having a ucid attribute into a separate
  -- row so that we can create a row for each ucid along with the dnum-type
  WITH patcit_nodes AS (
    SELECT
      c.publication_id,
      UNNEST(XPATH('/citations/patent-citations/patcit[@ucid]', c.content)) AS patcit_node,
      c.modified_load_id
    FROM
      xml.t_patent_document_values AS p
        INNER JOIN
      xml.t_citations AS c
        ON p.publication_id = c.publication_id
    WHERE
      p.modified_load_id = v_load_id
  )
  INSERT INTO t_tmp_cited_documents (publication_id, cited_ucid, source, is_app, load_id)
  SELECT
    publication_id,
    ARRAY_TO_STRING(XPATH('@ucid', patcit_node), ''),
    CASE
      WHEN XMLEXISTS('sources/source/@name' PASSING patcit_node) THEN UNNEST(XPATH('sources/source/@name', patcit_node))
      ELSE 'UNKNOWN'
    END,
    CASE
      WHEN ARRAY_TO_STRING(XPATH('@dnum-type', patcit_node), '') = 'application' THEN TRUE
      ELSE FALSE   
    END,
    modified_load_id
  FROM patcit_nodes;

  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - inserted % citation records into the work table', v_load_id, v_total;

  -- add publication_ids from t_patent_document_values for found publications
  UPDATE
    t_tmp_cited_documents AS tmp 
  SET
    cited_document_id = p.publication_id
  FROM
    xml.t_patent_document_values AS p
  WHERE
    tmp.cited_ucid = p.ucid
    AND tmp.is_app IS FALSE;

  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - updated % citation records in the work table', v_load_id, v_total;

  -- TODO: once the applications table is set up we need to update the applications

  -- delete phantoms from the temp work table
  DELETE
  FROM
    t_tmp_cited_documents
  WHERE 
    cited_document_id IS NULL;

  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - deleted % phantom citation records from the work table', v_load_id, v_total;

  -- delete duplicates from the temp work table

  -- QUERY 1 - EXISTS
  --  Delete on t_tmp_cited_documents tmp1  (cost=41.62..114.75 rows=96 width=12)
  DELETE
  FROM
    t_tmp_cited_documents AS tmp1
  WHERE
    EXISTS (
      SELECT
        1
      FROM
        t_tmp_cited_documents AS tmp2
      WHERE
        tmp1.publication_id = tmp2.publication_id
        AND tmp1.cited_document_id = tmp2.cited_document_id
        AND tmp1.source = tmp2.source
        AND tmp1.is_app = tmp2.is_app
        AND tmp1.ctid > tmp2.ctid
    );

  -- QUERY 2 DELETE USING
  -- Delete on t_tmp_cited_documents tmp1  (cost=159.93..183.14 rows=6 width=12)
  --DELETE
  --FROM
  --  t_tmp_cited_documents AS tmp1
  --USING
  --  t_tmp_cited_documents AS tmp2 
  --WHERE
  --  tmp1.publication_id = tmp2.publication_id
  --  AND tmp1.cited_document_id = tmp2.cited_document_id
  --  AND tmp1.source = tmp2.source
  --  AND tmp1.is_app = tmp2.is_app
  --  AND tmp1.ctid > tmp2.ctid;

  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - deleted % duplicate citation records from the work table', v_load_id, v_total;

  -- delete records from the load-id that have no citations in the temp table
  -- but have citations listed in our linking table meaning the citations
  -- were deleted from the xml table at some point

  -- QUERY 1 USING LEFT OUTER JOIN
  --  Delete on t_cited_documents cd  (cost=291.93..332.97 rows=2 width=18)
  DELETE
  FROM
    cdws.t_cited_documents AS cd
  USING
    xml.t_patent_document_values AS p
      LEFT OUTER JOIN
    t_tmp_cited_documents AS tmp
      ON p.publication_id = tmp.publication_id
  WHERE
    p.modified_load_id = v_load_id
    AND cd.publication_id = p.publication_id
    AND tmp.publication_id IS NULL;

  -- QUERY 2 EXISTS + NOT EXISTS
  -- Delete on t_cited_documents cd  (cost=291.93..356.67 rows=472 width=18)
  --DELETE
  --FROM
  --  cdws.t_cited_documents AS cd
  --WHERE
  --  EXISTS (
  --    SELECT
  --      1
  --    FROM
  --      xml.t_patent_document_values AS p
  --    WHERE
  --      cd.publication_id = p.publication_id
  --      AND p.modified_load_id = v_load_id
  --  )
  --  AND NOT EXISTS (
  --    SELECT
  --      1
  --    FROM
  --      t_tmp_cited_documents AS tmp
  --    WHERE
  --      cd.publication_id = tmp.publication_id
  --  );    
    
  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - deleted % removed citation records from the main table', v_load_id, v_total;

  -- simple way to update, delete all existing rows from the main table
  -- and insert all rows from the temp table, this works but is currently
  -- commented out in favor of the less disruptive options below
  --DELETE
  --FROM
  --  cdws.t_cited_documents cd
  --USING
  --  t_tmp_cited_documents tmp
  --WHERE
  --  cd.publication_id = tmp.publication_id;

  --INSERT INTO cdws.t_cited_documents (publication_id, cited_document_id, source, is_app, load_id)
  --SELECT publication_id, cited_document_id, source, is_app, load_id FROM t_tmp_cited_documents;


  -- below are the attempts to minimize deletes and inserts by comparing the
  -- main and tmp cited documents tables

  -- first delete rows from the main table that do not exist in the work table
  -- NOTE: listed below are three ways to do this in order of lowest to highest
  -- cost based on minimal tests with a small sample set
  -- NOTE (20170505): with more than 250 million rows in the main cited
  -- documents table it became necessary to switch the active query here,
  -- the preferred order now is query 2, query 3, query 1

  -- QUERY 1 EXISTS + NOT EXISTS
  -- Delete on t_cited_documents cd  (cost=210.43..231.52 rows=709 width=18)
  --DELETE
  --FROM
  --  cdws.t_cited_documents AS cd
  --WHERE
  --  EXISTS (
  --    SELECT
  --      1
  --    FROM
  --      t_tmp_cited_documents AS tmp1
  --    WHERE
  --      cd.publication_id = tmp1.publication_id
  --  )
  --  AND NOT EXISTS (
  --    SELECT
  --      1
  --    FROM
  --      t_tmp_cited_documents AS tmp2
  --    WHERE
  --      cd.publication_id = tmp2.publication_id
  --      AND cd.cited_document_id = tmp2.cited_document_id
  --      AND cd.source = tmp2.source
  --      AND cd.is_app = tmp2.is_app
  --  );

  -- QUERY 2 CTE JOIN + NOT EXISTS
  -- Delete on t_cited_documents cd  (cost=249.74..302.68 rows=1418 width=40)
  WITH ids AS (
    SELECT
      DISTINCT(publication_id)
    FROM
      t_tmp_cited_documents
  )    
  DELETE
  FROM
    cdws.t_cited_documents AS cd
  USING
    ids
  WHERE
    cd.publication_id = ids.publication_id
    AND NOT EXISTS (
      SELECT 1
      FROM t_tmp_cited_documents AS tmp
      WHERE
        cd.publication_id = tmp.publication_id
        AND cd.cited_document_id = tmp.cited_document_id
        AND cd.source = tmp.source
        AND cd.is_app = tmp.is_app
    );

  -- QUERY 3 INNER JOIN USING + NOT EXISTS
  -- Delete on t_cited_documents cd  (cost=291.68..448.21 rows=8151 width=18)
  --DELETE
  --FROM
  --  cdws.t_cited_documents AS cd
  --USING
  --  t_tmp_cited_documents AS tmp1
  --WHERE
  --  cd.publication_id = tmp1.publication_id
  --  AND NOT EXISTS (
  --    SELECT 1
  --    FROM t_tmp_cited_documents AS tmp2
  --    WHERE
  --      cd.publication_id = tmp2.publication_id
  --      AND cd.cited_document_id = tmp2.cited_document_id
  --      AND cd.source = tmp2.source
  --      AND cd.is_app = tmp2.is_app
  --  );

  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - deleted % outdated citation records from the main table', v_load_id, v_total;

  -- next delete rows from the temp work table that also appear in the main table
  DELETE
  FROM
    t_tmp_cited_documents AS tmp
  WHERE
    EXISTS (
      SELECT
        1
      FROM
        cdws.t_cited_documents AS cd
      WHERE
        tmp.publication_id = cd.publication_id
        AND tmp.cited_document_id = cd.cited_document_id
        AND tmp.source = cd.source
        AND tmp.is_app = cd.is_app
    );

  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - deleted % unchanged citation records from the work table', v_load_id, v_total;

  -- now insert whatever is left over in the work table
  INSERT INTO cdws.t_cited_documents (publication_id, cited_document_id, source, is_app, load_id)
  SELECT publication_id, cited_document_id, source, is_app, load_id FROM t_tmp_cited_documents;

  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - added % new citation records from the work table', v_load_id, v_total;

END;
$$;


--
-- Name: f_update_priority_documents(integer); Type: FUNCTION; Schema: cdws; Owner: -
--

CREATE FUNCTION cdws.f_update_priority_documents(v_load_id integer) RETURNS void
    LANGUAGE plpgsql STRICT
    AS $$

DECLARE
  v_total integer;
  v_start_time timestamp;
BEGIN

  CREATE TEMPORARY TABLE IF NOT EXISTS t_tmp_priority_documents (
    publication_id integer NOT NULL,
    application_ucid text NOT NULL,
    application_id integer,
    app_type char(1) NOT NULL,
    link char(1),
    filed date,
    load_id integer NOT NULL
  ) ON COMMIT DROP;
  TRUNCATE TABLE t_tmp_priority_documents;

  -- first pull out each priority node having a ucid attribute into a separate
  -- row so that we can create a row for each priority ucid
  v_start_time := clock_timestamp();
  WITH priority_nodes AS (
    SELECT
      c.publication_id,
      UNNEST(XPATH('/priority-claims/priority-claim[@ucid and @load-source="docdb"]', c.content)) AS priority_node,
      c.modified_load_id
    FROM
      xml.t_patent_document_values AS p
        INNER JOIN
      xml.t_priority_claims AS c
        ON p.publication_id = c.publication_id
    WHERE
      p.modified_load_id = v_load_id
  )
  INSERT INTO t_tmp_priority_documents (publication_id, application_ucid, app_type, link, filed, load_id)
  SELECT
    publication_id,
    ARRAY_TO_STRING(XPATH('/priority-claim/@ucid', priority_node), ''),
    'P',
    NULLIF(ARRAY_TO_STRING(XPATH('/priority-claim/@linkage-type', priority_node), ''), ''),
    TO_DATE(NULLIF(ARRAY_TO_STRING(XPATH('(/priority-claim/document-id/date/text()[normalize-space()])[1]', priority_node), ''), ''), 'yyyymmdd'),
    modified_load_id
  FROM priority_nodes;

  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - inserted % priority records into the work table (%s)',
    v_load_id, v_total, ROUND(CAST(EXTRACT(epoch FROM clock_timestamp() - v_start_time) AS NUMERIC), 3);

  -- 20190305 - add applications to the priorities table regardless of whether
  -- or not the application was also listed as a priority, the old extract
  -- format included the load-source attribute on the application-reference
  -- and the current format includes it on document-id
  v_start_time := clock_timestamp();
  WITH application_info AS (
    WITH application_nodes AS (
      SELECT
        a.publication_id,
        UNNEST(XPATH('/application-reference/document-id[@format="epo" and ancestor-or-self::*[@load-source="docdb"]]', a.content)) AS application_node,
        a.modified_load_id
      FROM
        xml.t_patent_document_values AS p
          INNER JOIN
        xml.t_application_reference AS a
          ON p.publication_id = a.publication_id
      WHERE
        p.modified_load_id = v_load_id
    )
    SELECT
      publication_id,
      CONCAT_WS('-', 
        ARRAY_TO_STRING(XPATH('/document-id/country/text()', application_node), ''),
        ARRAY_TO_STRING(XPATH('/document-id/doc-number/text()', application_node), ''),
        ARRAY_TO_STRING(XPATH('/document-id/kind/text()', application_node), '')
      ) AS application_ucid,
      'A' AS app_type,
      NULL AS link,
      TO_DATE(NULLIF(ARRAY_TO_STRING(XPATH('(/document-id/date/text()[normalize-space()])[1]', application_node), ''), ''), 'yyyymmdd') AS filed,
      modified_load_id as load_id
    FROM
      application_nodes
  )
  INSERT INTO t_tmp_priority_documents (publication_id, application_ucid, app_type, link, filed, load_id)
  -- insert all applications regardless if a matching priority exists
  SELECT * FROM application_info;

  -- or only insert applications when a matching priority does not exist
  --SELECT
  --  a.*
  --FROM
  --  application_info AS a
  --    LEFT OUTER JOIN
  --  t_tmp_priority_documents AS t
  --    ON a.publication_id = t.publication_id
  --    AND a.application_ucid = t.application_ucid
  --WHERE
  --  t.publication_id IS NULL;

  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - inserted % application records into the work table (%s)',
    v_load_id, v_total, ROUND(CAST(EXTRACT(epoch FROM clock_timestamp() - v_start_time) AS NUMERIC), 3);
  
  -- add application_ids from cdws.t_applications
  v_start_time := clock_timestamp();
  --UPDATE
  --  t_tmp_priority_documents 
  --SET
  --  application_id = cdws.f_upsert_application(application_ucid, filed, TRUE);

  WITH app_ids AS (
    SELECT
      application_ucid,
      cdws.f_upsert_application(application_ucid, filed, TRUE) AS application_id
    FROM
      t_tmp_priority_documents
    ORDER BY
      publication_id,
      app_type,
      application_ucid
  )
  UPDATE t_tmp_priority_documents tmp
  SET application_id = app_ids.application_id
  FROM app_ids
  WHERE app_ids.application_ucid = tmp.application_ucid;
  
  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - updated % priority records in the work table (%s)',
    v_load_id, v_total, ROUND(CAST(EXTRACT(epoch FROM clock_timestamp() - v_start_time) AS NUMERIC), 3);

  -- delete phantoms from the temp work table
  v_start_time := clock_timestamp();
  DELETE
  FROM
    t_tmp_priority_documents
  WHERE 
    application_id IS NULL;

  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - deleted % phantom priority records from the work table (%s)',
    v_load_id, v_total, ROUND(CAST(EXTRACT(epoch FROM clock_timestamp() - v_start_time) AS NUMERIC), 3);

  -- delete duplicates from the temp work table, ignore filing date
  v_start_time := clock_timestamp();
  DELETE
  FROM
    t_tmp_priority_documents AS tmp1
  WHERE
    EXISTS (
      SELECT
        1
      FROM
        t_tmp_priority_documents AS tmp2
      WHERE
        tmp1.publication_id = tmp2.publication_id
        AND tmp1.application_id = tmp2.application_id
        AND tmp1.app_type = tmp2.app_type
        AND tmp1.link IS NOT DISTINCT FROM tmp2.link
        --AND tmp1.filed IS NOT DISTINCT FROM tmp2.filed
        AND tmp1.ctid > tmp2.ctid
    );

  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - deleted % duplicate priority records from the work table (%s)',
    v_load_id, v_total, ROUND(CAST(EXTRACT(epoch FROM clock_timestamp() - v_start_time) AS NUMERIC), 3);

  -- delete records from the load-id that have no priority in the temp table
  -- but have priorities listed in our linking table meaning the priorities
  -- were deleted from the xml table at some point
  v_start_time := clock_timestamp();
  DELETE
  FROM
    cdws.t_priority_documents AS pd
  USING
    xml.t_patent_document_values AS p
      LEFT OUTER JOIN
    t_tmp_priority_documents AS tmp
      ON p.publication_id = tmp.publication_id
  WHERE
    p.modified_load_id = v_load_id
    AND pd.publication_id = p.publication_id
    AND tmp.publication_id IS NULL;
    
  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - deleted % removed priority records from the main table (%s)',
    v_load_id, v_total, ROUND(CAST(EXTRACT(epoch FROM clock_timestamp() - v_start_time) AS NUMERIC), 3);
  
  -- delete from the main table any records not found in the work table
  v_start_time := clock_timestamp();
  WITH ids AS (
    WITH pubs AS (
      SELECT DISTINCT publication_id
      FROM t_tmp_priority_documents
      ORDER BY publication_id
    )
    SELECT
      pd.priority_id
    FROM
      pubs
        INNER JOIN
      cdws.t_priority_documents AS pd
        ON pubs.publication_id = pd.publication_id
        LEFT OUTER JOIN
      t_tmp_priority_documents AS tmp
        ON pd.publication_id = tmp.publication_id
        AND pd.application_id = tmp.application_id
        AND pd.app_type = tmp.app_type
        AND pd.link IS NOT DISTINCT FROM tmp.link
    WHERE
      tmp.publication_id IS NULL
    ORDER BY
      pd.priority_id
  )
  DELETE from cdws.t_priority_documents pd
  USING ids
  WHERE pd.priority_id = ids.priority_id;
    
  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - deleted % outdated priority records from the main table (%s)',
    v_load_id, v_total, ROUND(CAST(EXTRACT(epoch FROM clock_timestamp() - v_start_time) AS NUMERIC), 3);
  
  -- now insert records from the work table to do not exist in the main table
  INSERT INTO cdws.t_priority_documents (publication_id, application_id, app_type, link, load_id)
    SELECT
      tmp.publication_id,
      tmp.application_id,
      tmp.app_type,
      tmp.link,
      tmp.load_id
    FROM
      t_tmp_priority_documents AS tmp
        LEFT OUTER JOIN
      cdws.t_priority_documents AS pd
        ON tmp.publication_id = pd.publication_id
        AND tmp.application_id = pd.application_id
        AND tmp.app_type = pd.app_type
        AND tmp.link IS NOT DISTINCT FROM pd.link
    WHERE
      pd.publication_id IS NULL
    ORDER BY
      tmp.publication_id,
      tmp.app_type,
      tmp.application_id;

  GET DIAGNOSTICS v_total = ROW_COUNT;
  RAISE INFO 'load-id % - added % new priority records from the work table (%s)',
    v_load_id, v_total, ROUND(CAST(EXTRACT(epoch FROM clock_timestamp() - v_start_time) AS NUMERIC), 3);

END;

$$;


--
-- Name: f_upsert_application(text, date, boolean); Type: FUNCTION; Schema: cdws; Owner: -
--

CREATE FUNCTION cdws.f_upsert_application(v_app_ucid text, v_app_filed date, v_overwrite boolean DEFAULT false, OUT v_app_id integer) RETURNS integer
    LANGUAGE plpgsql
    AS $$
BEGIN
 
  LOOP
    -- first try to locate an existing application record
    SELECT
      application_id
    INTO
      v_app_id
    FROM
      cdws.t_applications
    WHERE
      application_ucid = v_app_ucid;
      
    IF FOUND THEN
      IF v_overwrite IS TRUE THEN
        UPDATE
          cdws.t_applications
        SET
          filed = v_app_filed
        WHERE
          application_id = v_app_id
          and filed != v_app_filed;
      END IF;

      RETURN;
    END IF;
    
    -- not there, try to insert the record, but if someone else inserts the
    -- same key concurrently we should get a unique key failure
    BEGIN
      INSERT INTO
        cdws.t_applications (application_ucid, filed)
      VALUES
        (v_app_ucid, v_app_filed)
      RETURNING
        application_id
      INTO
        v_app_id;

      RETURN;

    EXCEPTION WHEN unique_violation THEN
      -- do nothing, loop and try the SELECT again.
    END;
  END LOOP;
  
END;

$$;

