#! /usr/bin/env perl

use strict;
use warnings;
use Getopt::Long;
use Alexandria::Database::Connection;
use Data::Dumper;

sub _usage {
  my $str = <<EOS;

  $0 [ Options ... ]
  
  --pgdbname=s         Entry in /etc/alexandria.xml or the active configuration
                       file as shown from the tool acfg (default=alexandria)
  --psqlexe=s          Specify location of psql (default is the psql found in PATH)
    --no-psql          If you would like to run the bulk SCHEMA updates manually,
                       use this option (NOTE: only applies if psql is not found)

    TABLESPACES (optional)
    ----------------
  --tblspc_xmltxt=s    If applicable, the TABLESPACE containing the XML schema tables
  --tblspc_xmlidx=s    If applicable, the TABLESPACE containing the XML schema indices
  --tblspc_wrktxt=s    If applicable, the TABLESPACE containing the WORK schema tables
  --tblspc_wrkidx=s    If applicable, the TABLESPACE containing the WORK schema indices

  --help               Print this usage and exit

EOS
  return $str;
}

sub _get_options {
  my %opts = (
    pgdbname => 'alexandria',
    psqlexe => 'psql',
  );
  if( !GetOptions( \%opts,
      'pgdbname=s',
      'psqlexe=s',
        'no-psql',
      'tblspc_xmltxt=s',
      'tblspc_xmlidx=s',
      'tblspc_wrktxt=s',
      'tblspc_wrkidx=s',
      'help' ) || $opts{help} ) { die _usage(); }
  return \%opts;
}

sub _conn {
  my $pgdbname = shift;
  my $conn = eval {
    Alexandria::Database::Connection->new( name => $pgdbname );
  };
  if($@) { die $@; }
  return $conn;
}

sub _read_file {
  my $file = shift;
  my $data;

  open( F, "< $file" ) || die "$file: $!\n";
  while( <F> ) { $data .= $_; }
  close( F );
  return $data;
}

sub _psql_exists {
  my $options = shift;
  my $cmd = $options->{psqlexe};
  # test if absolute path
  if( !( -f $cmd  ) ) {
    for my $path ( split /:/, $ENV{PATH} ) {
      if ( -f "$path/$cmd" && -x _ ) {
        return 1;
      }
    }
    return 0;
  }
  return 1;
}

sub _tablespace_exists {
  my $options = shift;
  my $tblspc = shift;
  my $c = $options->{c};
  my $sth = $c->dbh->prepare( "select count(*) from pg_tablespace where spcname = ?" );
  $sth->execute( $tblspc );
  my ( $ret ) = $sth->fetchrow_array();
  $sth->finish();
  return $ret;
}

sub _schema_exists {
  my $options = shift;
  my $schema = shift;
  my $c = $options->{c};
  my $sth = $c->dbh->prepare( "select count(*) from pg_namespace where nspname = ?" );
  $sth->execute( $schema );
  my ( $ret ) = $sth->fetchrow_array();
  $sth->finish();
  return $ret;
}

sub _table_exists {
  my $options = shift;
  my $table = shift;
  my ( $schema, $tbl ) = split( /\./, $table->{name} );

  my $sql = "select count(*) table_name
             from information_schema.tables
             where table_schema = ? and table_name = ?";
  my $sth = $options->{c}->dbh->prepare( $sql );
  $sth->execute( $schema, $tbl );
  my ( $ret ) = $sth->fetchrow_array();
  $sth->finish();
  return $ret;

}

sub _create_tables {
  my $options = shift;
  my $tables = shift;

  foreach my $table ( @{ $tables } ) {
    print STDERR "-> $table->{name} ...";
    if( !_table_exists( $options, $table ) ) {

      print STDERR " missing! creating table + indices...";

      my $tsql = _read_file( $table->{t} );
      my $isql = _read_file( $table->{i} );
      my $c = $options->{c};

      if( $options->{tblspc_xmltxt} ) {
        if( !_tablespace_exists( $options, $options->{tblspc_xmltxt} ) ) {
          die "ERROR: TABLESPACE $options->{tblspc_xmltxt} does not exist!\n";
        }
        $c->dbh->do( "set default_tablespace = $options->{tblspc_xmltxt}" );
      }
      $c->dbh->do( $tsql );

      if( $options->{tblspc_xmlidx} ) {
        if( !_tablespace_exists( $options,  $options->{tblspc_xmlidx} ) ) {
          die "ERROR: TABLESPACE $options->{tblspc_xmlidx} does not exist!\n";
        }
        $c->dbh->do( "set default_tablespace = $options->{tblspc_xmlidx}" );
      }
      $c->dbh->do( $isql );

      print STDERR " done!\n";

    }
    else {
      print STDERR " present!\n";
    }
  }
}

sub _recreate_functions {
  my $options = shift;
  my $fns = shift;

  foreach my $fn ( @{ $fns } ) {
    print STDERR "-> $fn->{name} ...";
    my $fsql = _read_file( $fn->{f} );
    my $c = $options->{c};
    $c->dbh->do( $fsql );
    print STDERR " done!\n";
  }
}

sub _recreate_schemas {
  my $options = shift;
  my $schemas = shift;

  # this section requires psql to be installed
  my $psql = $options->{psqlexe}; # verified to exist

  # 'name' => 'alexandria',
  # 'port' => '5432',
  # 'dbname' => 'alexandria',
  # 'host' => '192.168.101.24',
  # We grab the connection information from the Connection object;
  my $host = $options->{c}->{host};
  my $port = $options->{c}->{port};
  my $db   = $options->{c}->{dbname};

  print STDERR "-> using $host:$port ($db)\n";
  `rm -f SCHEMA-ERRORS.txt`;
  foreach my $schema ( @{ $schemas } ) {
    print STDERR "-> $schema->{name} ...";
    # print STDERR " $psql -Ualexandria -h $host -p $port $db < $schema->{s}";
    my $out = `$psql -Ualexandria -h $host -p $port $db < $schema->{s} 2>>SCHEMA-ERRORS.txt`;
    my $errors = `grep -c ^ERRORS SCHEMA-ERRORS.txt`;
    chomp( $errors );
    if( $errors > 0 ) {
      print STDERR "ERRORS DETECTED. Please see SCHEMA-ERRORS.txt";
    }
    print STDERR " done!\n";
  }
}



#### MAIN
my $options = _get_options();
$options->{c} = _conn( $options->{pgdbname} );

if( !_psql_exists( $options ) ) {
  print STDERR "WARNING: No psql found!\n";
  if( $options->{'no-psql'} ) {
    local $| = 1;
    print "NOTICE: You have specified --no-psql.\n";
    print "\nYou will be required to manually complete this upgrade. Please see the README\n";
    print "for manual directions to complete this upgrade or contact support\@ificlaims.com\n";
    print "\nWould you like to continue with partial modifications? (y/n): ";
    my $response;
    chomp( $response = <STDIN> );
    if( lc( $response ) ne 'y' ) {
      exit 1;
    }
    $options->{skip_schemas} = 1;
  }
  else {
    print STDERR "Installation cannot continue.\n";
    print STDERR "\nIf you are comfortable manually completing the upgrade, please\n";
    print STDERR "see the README and use the --no-psql option or, contact support\@ificlaims.com\n";
    exit 1;
  }
}

# new tables
my @tables = (
  { name => 'xml.t_ifi_integrated_content',  t => 'SQL/t1.sql', i => 'SQL/i1.sql' },
  { name => 'xml.t_ifi_annotated_data',      t => 'SQL/t2.sql', i => 'SQL/i2.sql' },
  { name => 'xml.t_statistical_information', t => 'SQL/t3.sql', i => 'SQL/i3.sql' },
  { name => 'xml.t_keywords',                t => 'SQL/t4.sql', i => 'SQL/i4.sql' }
);

my @functions = (
  { name => 'xml.f_copyright',         f => 'SQL/f3.sql' },
  { name => 'xml.f_patent_document',   f => 'SQL/f1.sql' },
  { name => 'xml.f_patent_document_s', f => 'SQL/f2.sql' },
);

my @schemas = (
  { name => 'work',      s => 'SQL/s1.sql' },
  { name => 'cdws',      s => 'SQL/s3.sql' },
  { name => 'api',       s => 'SQL/s2.sql' },
  { name => 'reports',   s => 'SQL/s4.sql' },
);

#print STDERR Dumper( $options->{c} ); exit;

# 1) TABLES
print STDERR "Verifying necessary tables:\n";
_create_tables( $options, \@tables );

print STDERR "Updating necessary functions:\n";
_recreate_functions( $options, \@functions );

if( !$options->{skip_schemas} ) {
  print STDERR "Creating/Updating schemas:\n";
  _recreate_schemas( $options, \@schemas );
}


